from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UndoCls:
	"""Undo commands group definition. 5 total commands, 3 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("undo", core, parent)

	@property
	def hclear(self):
		"""hclear commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hclear'):
			from .Hclear import HclearCls
			self._hclear = HclearCls(self._core, self._cmd_group)
		return self._hclear

	@property
	def hid(self):
		"""hid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hid'):
			from .Hid import HidCls
			self._hid = HidCls(self._core, self._cmd_group)
		return self._hid

	@property
	def hlable(self):
		"""hlable commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_hlable'):
			from .Hlable import HlableCls
			self._hlable = HlableCls(self._core, self._cmd_group)
		return self._hlable

	def get_state(self) -> bool:
		"""SCPI: SYSTem:UNDO:STATe \n
		Snippet: value: bool = driver.system.undo.get_state() \n
		No command help available \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('SYSTem:UNDO:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: SYSTem:UNDO:STATe \n
		Snippet: driver.system.undo.set_state(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SYSTem:UNDO:STATe {param}')

	def clone(self) -> 'UndoCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = UndoCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.TrigMarkMode, output=repcap.Output.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TRIGger:OUTPut<CH>:MODE \n
		Snippet: driver.source.bb.arbitrary.trigger.output.mode.set(mode = enums.TrigMarkMode.PATTern, output = repcap.Output.Default) \n
		The command defines the signal for the selected marker output. \n
			:param mode: UNCHanged| RESTart| PULSe| PATTern| RATio UNCHanged A marker signal as defined in the waveform file (tag 'marker mode x') is generated. RESTart A marker signal is generated at every waveform start. PULSe A pulsed marker signal is generated. The pulse frequency (= sample rate/divider) is defined with the SOUR:BB:ARB:TRIG:OUTP:PULS:DIV command and can be queried with the SOUR:BB:ARB:TRIG:OUTP:PULS:FREQ? command. PATTern A marker signal is generated with the aid of a user-definable bit pattern. The bit pattern is entered with the aid of command :BB:ARB:TRIGger:OUTPut:PATTern. The bit pattern is a maximum of 32 bits long. RATio A regular marker signal corresponding to the Time Off / Time On specifications in the commands :ARB:TRIGger:OUTPut:OFFTime and :ARB:TRIGger:OUTPut:ONTime is generated.
			:param output: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.TrigMarkMode)
		output_cmd_val = self._cmd_group.get_repcap_cmd_value(output, repcap.Output)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:TRIGger:OUTPut{output_cmd_val}:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, output=repcap.Output.Default) -> enums.TrigMarkMode:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TRIGger:OUTPut<CH>:MODE \n
		Snippet: value: enums.TrigMarkMode = driver.source.bb.arbitrary.trigger.output.mode.get(output = repcap.Output.Default) \n
		The command defines the signal for the selected marker output. \n
			:param output: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:return: mode: UNCHanged| RESTart| PULSe| PATTern| RATio UNCHanged A marker signal as defined in the waveform file (tag 'marker mode x') is generated. RESTart A marker signal is generated at every waveform start. PULSe A pulsed marker signal is generated. The pulse frequency (= sample rate/divider) is defined with the SOUR:BB:ARB:TRIG:OUTP:PULS:DIV command and can be queried with the SOUR:BB:ARB:TRIG:OUTP:PULS:FREQ? command. PATTern A marker signal is generated with the aid of a user-definable bit pattern. The bit pattern is entered with the aid of command :BB:ARB:TRIGger:OUTPut:PATTern. The bit pattern is a maximum of 32 bits long. RATio A regular marker signal corresponding to the Time Off / Time On specifications in the commands :ARB:TRIGger:OUTPut:OFFTime and :ARB:TRIGger:OUTPut:ONTime is generated."""
		output_cmd_val = self._cmd_group.get_repcap_cmd_value(output, repcap.Output)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ARBitrary:TRIGger:OUTPut{output_cmd_val}:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.TrigMarkMode)



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PatternCls:
	"""Pattern commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pattern", core, parent)

	def set(self, pattern: List[str], bitcount: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:XMRadio:DATA:PATTern \n
		Snippet: driver.source.bb.xmRadio.data.pattern.set(pattern = ['raw1', 'raw2', 'raw3'], bitcount = 1) \n
		No command help available \n
			:param pattern: No help available
			:param bitcount: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('pattern', pattern, DataType.RawStringList, None), ArgSingle('bitcount', bitcount, DataType.Integer))
		self._core.io.write(f'SOURce<HwInstance>:BB:XMRadio:DATA:PATTern {param}'.rstrip())

	# noinspection PyTypeChecker
	class PatternStruct(StructBase):
		"""Response structure. Fields: \n
			- Pattern: List[str]: No parameter help available
			- Bitcount: int: No parameter help available"""
		__meta_args_list = [
			ArgStruct('Pattern', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Pattern: List[str] = None
			self.Bitcount: int = None

	def get(self) -> PatternStruct:
		"""SCPI: [SOURce<HW>]:BB:XMRadio:DATA:PATTern \n
		Snippet: value: PatternStruct = driver.source.bb.xmRadio.data.pattern.get() \n
		No command help available \n
			:return: structure: for return value, see the help for PatternStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:XMRadio:DATA:PATTern?', self.__class__.PatternStruct())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SwapCls:
	"""Swap commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("swap", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:IQ:SWAP:[STATe] \n
		Snippet: value: bool = driver.source.iq.swap.get_state() \n
		When set to ON, this command swaps the I and Q channel. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:SWAP:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:IQ:SWAP:[STATe] \n
		Snippet: driver.source.iq.swap.set_state(state = False) \n
		When set to ON, this command swaps the I and Q channel. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:IQ:SWAP:STATe {param}')



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	def get_points(self) -> int:
		"""SCPI: [SOURce<HW>]:CORRection:CSET:DATA:FREQuency:POINts \n
		Snippet: value: int = driver.source.correction.cset.data.frequency.get_points() \n
		Queries the number of frequency values in the selected table. The numerical suffix at SOURce must not be used for this
		command. \n
			:return: points: integer Range: 0 to 10000
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:CORRection:CSET:DATA:FREQuency:POINts?')
		return Conversions.str_to_int(response)

	def get_value(self) -> List[float]:
		"""SCPI: [SOURce<HW>]:CORRection:CSET:DATA:FREQuency \n
		Snippet: value: List[float] = driver.source.correction.cset.data.frequency.get_value() \n
		Transfers the frequency data to the table selected with CORRection:CSET:SELect. The numerical suffix at SOURce must not
		be used for this command. \n
			:return: frequency: Frequency#1[, Frequency#2, ...] Range: 300 kHz to RFmax (depending on model)
		"""
		response = self._core.io.query_bin_or_ascii_float_list('SOURce<HwInstance>:CORRection:CSET:DATA:FREQuency?')
		return response

	def set_value(self, frequency: List[float]) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:CSET:DATA:FREQuency \n
		Snippet: driver.source.correction.cset.data.frequency.set_value(frequency = [1.1, 2.2, 3.3]) \n
		Transfers the frequency data to the table selected with CORRection:CSET:SELect. The numerical suffix at SOURce must not
		be used for this command. \n
			:param frequency: Frequency#1[, Frequency#2, ...] Range: 300 kHz to RFmax (depending on model)
		"""
		param = Conversions.list_to_csv_str(frequency)
		self._core.io.write(f'SOURce<HwInstance>:CORRection:CSET:DATA:FREQuency {param}')



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Types import DataType
from ....Internal.Utilities import trim_str_response
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TimeCls:
	"""Time commands group definition. 11 total commands, 3 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("time", core, parent)

	@property
	def daylightSavingTime(self):
		"""daylightSavingTime commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_daylightSavingTime'):
			from .DaylightSavingTime import DaylightSavingTimeCls
			self._daylightSavingTime = DaylightSavingTimeCls(self._core, self._cmd_group)
		return self._daylightSavingTime

	@property
	def hrTimer(self):
		"""hrTimer commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_hrTimer'):
			from .HrTimer import HrTimerCls
			self._hrTimer = HrTimerCls(self._core, self._cmd_group)
		return self._hrTimer

	@property
	def zone(self):
		"""zone commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_zone'):
			from .Zone import ZoneCls
			self._zone = ZoneCls(self._core, self._cmd_group)
		return self._zone

	def set(self, hour: List[int], minute: int, second: int) -> None:
		"""SCPI: SYSTem:TIME \n
		Snippet: driver.system.time.set(hour = [1, 2, 3], minute = 1, second = 1) \n
		No command help available \n
			:param hour: No help available
			:param minute: No help available
			:param second: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('hour', hour, DataType.IntegerList, None), ArgSingle('minute', minute, DataType.Integer), ArgSingle('second', second, DataType.Integer))
		self._core.io.write(f'SYSTem:TIME {param}'.rstrip())

	# noinspection PyTypeChecker
	class TimeStruct(StructBase):
		"""Response structure. Fields: \n
			- Hour: List[int]: No parameter help available
			- Minute: int: No parameter help available
			- Second: int: No parameter help available"""
		__meta_args_list = [
			ArgStruct('Hour', DataType.IntegerList, None, False, True, 1),
			ArgStruct.scalar_int('Minute'),
			ArgStruct.scalar_int('Second')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Hour: List[int] = None
			self.Minute: int = None
			self.Second: int = None

	def get(self) -> TimeStruct:
		"""SCPI: SYSTem:TIME \n
		Snippet: value: TimeStruct = driver.system.time.get() \n
		No command help available \n
			:return: structure: for return value, see the help for TimeStruct structure arguments."""
		return self._core.io.query_struct(f'SYSTem:TIME?', self.__class__.TimeStruct())

	def get_local(self) -> str:
		"""SCPI: SYSTem:TIME:LOCal \n
		Snippet: value: str = driver.system.time.get_local() \n
		No command help available \n
			:return: pseudo_string: No help available
		"""
		response = self._core.io.query_str('SYSTem:TIME:LOCal?')
		return trim_str_response(response)

	def set_local(self, pseudo_string: str) -> None:
		"""SCPI: SYSTem:TIME:LOCal \n
		Snippet: driver.system.time.set_local(pseudo_string = '1') \n
		No command help available \n
			:param pseudo_string: No help available
		"""
		param = Conversions.value_to_quoted_str(pseudo_string)
		self._core.io.write(f'SYSTem:TIME:LOCal {param}')

	def get_utc(self) -> str:
		"""SCPI: SYSTem:TIME:UTC \n
		Snippet: value: str = driver.system.time.get_utc() \n
		No command help available \n
			:return: pseudo_string: No help available
		"""
		response = self._core.io.query_str('SYSTem:TIME:UTC?')
		return trim_str_response(response)

	def set_utc(self, pseudo_string: str) -> None:
		"""SCPI: SYSTem:TIME:UTC \n
		Snippet: driver.system.time.set_utc(pseudo_string = '1') \n
		No command help available \n
			:param pseudo_string: No help available
		"""
		param = Conversions.value_to_quoted_str(pseudo_string)
		self._core.io.write(f'SYSTem:TIME:UTC {param}')

	def clone(self) -> 'TimeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TimeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TriggerCls:
	"""Trigger commands group definition. 20 total commands, 6 Subgroups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("trigger", core, parent)

	@property
	def arm(self):
		"""arm commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_arm'):
			from .Arm import ArmCls
			self._arm = ArmCls(self._core, self._cmd_group)
		return self._arm

	@property
	def delay(self):
		"""delay commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_delay'):
			from .Delay import DelayCls
			self._delay = DelayCls(self._core, self._cmd_group)
		return self._delay

	@property
	def execute(self):
		"""execute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_execute'):
			from .Execute import ExecuteCls
			self._execute = ExecuteCls(self._core, self._cmd_group)
		return self._execute

	@property
	def obaseband(self):
		"""obaseband commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_obaseband'):
			from .Obaseband import ObasebandCls
			self._obaseband = ObasebandCls(self._core, self._cmd_group)
		return self._obaseband

	@property
	def output(self):
		"""output commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_output'):
			from .Output import OutputCls
			self._output = OutputCls(self._core, self._cmd_group)
		return self._output

	@property
	def external(self):
		"""external commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_external'):
			from .External import ExternalCls
			self._external = ExternalCls(self._core, self._cmd_group)
		return self._external

	def get_ptime(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TRIGger:PTIMe \n
		Snippet: value: str = driver.source.bb.arbitrary.trigger.get_ptime() \n
		No command help available \n
			:return: arb_trig_proc_time: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:TRIGger:PTIMe?')
		return trim_str_response(response)

	# noinspection PyTypeChecker
	def get_rmode(self) -> enums.TrigRunMode:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TRIGger:RMODe \n
		Snippet: value: enums.TrigRunMode = driver.source.bb.arbitrary.trigger.get_rmode() \n
		The command queries the status of waveform output or all trigger modes with ARB on. \n
			:return: rmode: STOP| RUN RUN The waveform is output. A trigger event occurred in the triggered mode. STOP The waveform is not output. A trigger event did not occur in the triggered modes, or waveform output was stopped by the command:BB:ARB:TRIG:ARM:EXECute (armed trigger modes only) .
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:TRIGger:RMODe?')
		return Conversions.str_to_scalar_enum(response, enums.TrigRunMode)

	def get_slength(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TRIGger:SLENgth \n
		Snippet: value: int = driver.source.bb.arbitrary.trigger.get_slength() \n
		The command defines the length of the signal sequence to be output in the Single trigger mode. The unit is defined with
		command SOUR:BB:ARB:TRIG:SLUNit. It is possible to output deliberately just part of the waveform, an exact sequence of
		the waveform, or a defined number of repetitions of the waveform. \n
			:return: slength: integer Range: 1 to dynamic, Unit: sample
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:TRIGger:SLENgth?')
		return Conversions.str_to_int(response)

	def set_slength(self, slength: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TRIGger:SLENgth \n
		Snippet: driver.source.bb.arbitrary.trigger.set_slength(slength = 1) \n
		The command defines the length of the signal sequence to be output in the Single trigger mode. The unit is defined with
		command SOUR:BB:ARB:TRIG:SLUNit. It is possible to output deliberately just part of the waveform, an exact sequence of
		the waveform, or a defined number of repetitions of the waveform. \n
			:param slength: integer Range: 1 to dynamic, Unit: sample
		"""
		param = Conversions.decimal_value_to_str(slength)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:TRIGger:SLENgth {param}')

	# noinspection PyTypeChecker
	def get_sl_unit(self) -> enums.UnitSlB:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TRIGger:SLUNit \n
		Snippet: value: enums.UnitSlB = driver.source.bb.arbitrary.trigger.get_sl_unit() \n
		The command defines the unit for the entry of the length of the signal sequence (SOUR:BB:ARB:TRIG:SLEN) to be output in
		the 'Single' trigger mode (SOUR:BB:ARB:SEQ SING) . \n
			:return: sl_unit: SEQuence| SAMPle
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:TRIGger:SLUNit?')
		return Conversions.str_to_scalar_enum(response, enums.UnitSlB)

	def set_sl_unit(self, sl_unit: enums.UnitSlB) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TRIGger:SLUNit \n
		Snippet: driver.source.bb.arbitrary.trigger.set_sl_unit(sl_unit = enums.UnitSlB.SAMPle) \n
		The command defines the unit for the entry of the length of the signal sequence (SOUR:BB:ARB:TRIG:SLEN) to be output in
		the 'Single' trigger mode (SOUR:BB:ARB:SEQ SING) . \n
			:param sl_unit: SEQuence| SAMPle
		"""
		param = Conversions.enum_scalar_to_str(sl_unit, enums.UnitSlB)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:TRIGger:SLUNit {param}')

	# noinspection PyTypeChecker
	def get_smode(self) -> enums.ArbTrigSegmModeNoEhop:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TRIGger:SMODe \n
		Snippet: value: enums.ArbTrigSegmModeNoEhop = driver.source.bb.arbitrary.trigger.get_smode() \n
		The command selects the extended trigger mode for multi segment waveforms. \n
			:return: smode: SAME| NEXT| NSEam| SEQuencer NSEam = Next Segment Seamless
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:TRIGger:SMODe?')
		return Conversions.str_to_scalar_enum(response, enums.ArbTrigSegmModeNoEhop)

	def set_smode(self, smode: enums.ArbTrigSegmModeNoEhop) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TRIGger:SMODe \n
		Snippet: driver.source.bb.arbitrary.trigger.set_smode(smode = enums.ArbTrigSegmModeNoEhop.NEXT) \n
		The command selects the extended trigger mode for multi segment waveforms. \n
			:param smode: SAME| NEXT| NSEam| SEQuencer NSEam = Next Segment Seamless
		"""
		param = Conversions.enum_scalar_to_str(smode, enums.ArbTrigSegmModeNoEhop)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:TRIGger:SMODe {param}')

	# noinspection PyTypeChecker
	def get_source(self) -> enums.TriggerSourceB:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TRIGger:SOURce \n
		Snippet: value: enums.TriggerSourceB = driver.source.bb.arbitrary.trigger.get_source() \n
		Selects the trigger source. \n
			:return: source: INTernal| EXTernal INTernal manual trigger or *TRG. EXTernal trigger signal on the USER 1/2 connector.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:TRIGger:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.TriggerSourceB)

	def set_source(self, source: enums.TriggerSourceB) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TRIGger:SOURce \n
		Snippet: driver.source.bb.arbitrary.trigger.set_source(source = enums.TriggerSourceB.BEXTernal) \n
		Selects the trigger source. \n
			:param source: INTernal| EXTernal INTernal manual trigger or *TRG. EXTernal trigger signal on the USER 1/2 connector.
		"""
		param = Conversions.enum_scalar_to_str(source, enums.TriggerSourceB)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:TRIGger:SOURce {param}')

	# noinspection PyTypeChecker
	def get_sequence(self) -> enums.DmTrigMode:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:[TRIGger]:SEQuence \n
		Snippet: value: enums.DmTrigMode = driver.source.bb.arbitrary.trigger.get_sequence() \n
		The command selects the trigger mode. \n
			:return: sequence: AUTO| RETRigger| AAUTo| ARETrigger| SINGle AUTO The waveform is output continuously. RETRigger The waveform is output continuously. A trigger event (internal or external) causes a restart. AAUTo The waveform is output only when a trigger event occurs. After the trigger event the waveform is output continuously. Waveform output is stopped with command SOUR:BB:ARB:TRIG:ARM:EXEC and started again when a trigger event occurs. ARETrigger The waveform is output only when a trigger event occurs. The device automatically toggles to RETRIG mode. Every subsequent trigger event causes a restart. Waveform output is stopped with command SOUR:BB:ARB:TRIG:ARM:EXEC and started again when a trigger event occurs. SINGle The waveform is output only when a trigger event occurs. After the trigger event the waveform is output once to the set sequence length (SOUR:BB:ARB:TRIG:SLEN) . Every subsequent trigger event causes a restart.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:TRIGger:SEQuence?')
		return Conversions.str_to_scalar_enum(response, enums.DmTrigMode)

	def set_sequence(self, sequence: enums.DmTrigMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:[TRIGger]:SEQuence \n
		Snippet: driver.source.bb.arbitrary.trigger.set_sequence(sequence = enums.DmTrigMode.AAUTo) \n
		The command selects the trigger mode. \n
			:param sequence: AUTO| RETRigger| AAUTo| ARETrigger| SINGle AUTO The waveform is output continuously. RETRigger The waveform is output continuously. A trigger event (internal or external) causes a restart. AAUTo The waveform is output only when a trigger event occurs. After the trigger event the waveform is output continuously. Waveform output is stopped with command SOUR:BB:ARB:TRIG:ARM:EXEC and started again when a trigger event occurs. ARETrigger The waveform is output only when a trigger event occurs. The device automatically toggles to RETRIG mode. Every subsequent trigger event causes a restart. Waveform output is stopped with command SOUR:BB:ARB:TRIG:ARM:EXEC and started again when a trigger event occurs. SINGle The waveform is output only when a trigger event occurs. After the trigger event the waveform is output once to the set sequence length (SOUR:BB:ARB:TRIG:SLEN) . Every subsequent trigger event causes a restart.
		"""
		param = Conversions.enum_scalar_to_str(sequence, enums.DmTrigMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:TRIGger:SEQuence {param}')

	def clone(self) -> 'TriggerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TriggerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Types import DataType
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PointsCls:
	"""Points commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("points", core, parent)

	def get(self, board: str, sub_board: str) -> int:
		"""SCPI: DIAGnostic<HW>:EEPRom:DATA:POINts \n
		Snippet: value: int = driver.diagnostic.eeprom.data.points.get(board = '1', sub_board = '1') \n
		No command help available \n
			:param board: No help available
			:param sub_board: No help available
			:return: points: No help available"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('board', board, DataType.String), ArgSingle('sub_board', sub_board, DataType.String))
		response = self._core.io.query_str(f'DIAGnostic<HwInstance>:EEPRom:DATA:POINts? {param}'.rstrip())
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DispCls:
	"""Disp commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("disp", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.NoisAwgnDispModeRfBb:
		"""SCPI: [SOURce<HW>]:AWGN:DISP:MODE \n
		Snippet: value: enums.NoisAwgnDispModeRfBb = driver.source.awgn.disp.get_mode() \n
		Selects the display mode to Bseband or RF. \n
			:return: mode: RF| BB
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AWGN:DISP:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.NoisAwgnDispModeRfBb)

	# noinspection PyTypeChecker
	def get_oresults(self) -> enums.AnalogDigitalMode:
		"""SCPI: [SOURce<HW>]:AWGN:DISP:ORESults \n
		Snippet: value: enums.AnalogDigitalMode = driver.source.awgn.disp.get_oresults() \n
		(requires option R&S SGT-K18, Digital Baseband Connectivity) In additive Noise and Noise Only (SOUR:AWGN:MODE ADD|ONLY)
		modes and for Display Mode set to Baseband (AWGN:DISP:MODE BB) , selects the display of output results for the analog
		(DACIF) or the digital (BBOUT) signal path. \n
			:return: oresults: ANALog| DIGital
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AWGN:DISP:ORESults?')
		return Conversions.str_to_scalar_enum(response, enums.AnalogDigitalMode)

	def set_oresults(self, oresults: enums.AnalogDigitalMode) -> None:
		"""SCPI: [SOURce<HW>]:AWGN:DISP:ORESults \n
		Snippet: driver.source.awgn.disp.set_oresults(oresults = enums.AnalogDigitalMode.ANALog) \n
		(requires option R&S SGT-K18, Digital Baseband Connectivity) In additive Noise and Noise Only (SOUR:AWGN:MODE ADD|ONLY)
		modes and for Display Mode set to Baseband (AWGN:DISP:MODE BB) , selects the display of output results for the analog
		(DACIF) or the digital (BBOUT) signal path. \n
			:param oresults: ANALog| DIGital
		"""
		param = Conversions.enum_scalar_to_str(oresults, enums.AnalogDigitalMode)
		self._core.io.write(f'SOURce<HwInstance>:AWGN:DISP:ORESults {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LeakageCls:
	"""Leakage commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("leakage", core, parent)

	def get_icomponent(self) -> float:
		"""SCPI: [SOURce<HW>]:IQ:IMPairment:LEAKage:I \n
		Snippet: value: float = driver.source.iq.impairment.leakage.get_icomponent() \n
		Sets the carrier leakage amplitude for the I-signal component. \n
			:return: ipart: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:IMPairment:LEAKage:I?')
		return Conversions.str_to_float(response)

	def set_icomponent(self, ipart: float) -> None:
		"""SCPI: [SOURce<HW>]:IQ:IMPairment:LEAKage:I \n
		Snippet: driver.source.iq.impairment.leakage.set_icomponent(ipart = 1.0) \n
		Sets the carrier leakage amplitude for the I-signal component. \n
			:param ipart: float Range: -10 to 10
		"""
		param = Conversions.decimal_value_to_str(ipart)
		self._core.io.write(f'SOURce<HwInstance>:IQ:IMPairment:LEAKage:I {param}')

	def get_qcomponent(self) -> float:
		"""SCPI: [SOURce<HW>]:IQ:IMPairment:LEAKage:Q \n
		Snippet: value: float = driver.source.iq.impairment.leakage.get_qcomponent() \n
		Sets the carrier leakage amplitude for the Q-signal component. \n
			:return: qpart: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:IMPairment:LEAKage:Q?')
		return Conversions.str_to_float(response)

	def set_qcomponent(self, qpart: float) -> None:
		"""SCPI: [SOURce<HW>]:IQ:IMPairment:LEAKage:Q \n
		Snippet: driver.source.iq.impairment.leakage.set_qcomponent(qpart = 1.0) \n
		Sets the carrier leakage amplitude for the Q-signal component. \n
			:param qpart: float Range: -10 to 10
		"""
		param = Conversions.decimal_value_to_str(qpart)
		self._core.io.write(f'SOURce<HwInstance>:IQ:IMPairment:LEAKage:Q {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BbandCls:
	"""Bband commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bband", core, parent)

	# noinspection PyTypeChecker
	def get_slope(self) -> enums.SlopeType:
		"""SCPI: [SOURce<HW>]:INPut:TRIGger:[BBANd]:SLOPe \n
		Snippet: value: enums.SlopeType = driver.source.inputPy.trigger.bband.get_slope() \n
		No command help available \n
			:return: slope: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:INPut:TRIGger:BBANd:SLOPe?')
		return Conversions.str_to_scalar_enum(response, enums.SlopeType)

	def set_slope(self, slope: enums.SlopeType) -> None:
		"""SCPI: [SOURce<HW>]:INPut:TRIGger:[BBANd]:SLOPe \n
		Snippet: driver.source.inputPy.trigger.bband.set_slope(slope = enums.SlopeType.NEGative) \n
		No command help available \n
			:param slope: No help available
		"""
		param = Conversions.enum_scalar_to_str(slope, enums.SlopeType)
		self._core.io.write(f'SOURce<HwInstance>:INPut:TRIGger:BBANd:SLOPe {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OutputCls:
	"""Output commands group definition. 6 total commands, 2 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("output", core, parent)

	@property
	def error(self):
		"""error commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_error'):
			from .Error import ErrorCls
			self._error = ErrorCls(self._core, self._cmd_group)
		return self._error

	@property
	def iterations(self):
		"""iterations commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_iterations'):
			from .Iterations import IterationsCls
			self._iterations = IterationsCls(self._core, self._cmd_group)
		return self._iterations

	def get_cfactor(self) -> float:
		"""SCPI: [SOURce<HW>]:IQ:DPD:OUTPut:CFACtor \n
		Snippet: value: float = driver.source.iq.dpd.output.get_cfactor() \n
		Queries the measured values the before and after the enabled digital predistortion. \n
			:return: crest_factor: float The query returns -1000 if the calculation is impossible or there are no measurements results available.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:DPD:OUTPut:CFACtor?')
		return Conversions.str_to_float(response)

	def get_level(self) -> float:
		"""SCPI: [SOURce<HW>]:IQ:DPD:OUTPut:LEVel \n
		Snippet: value: float = driver.source.iq.dpd.output.get_level() \n
		Queries the measured values the before and after the enabled digital predistortion. \n
			:return: level: float The query returns -1000 if the calculation is impossible or there are no measurements results available.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:DPD:OUTPut:LEVel?')
		return Conversions.str_to_float(response)

	def get_pep(self) -> float:
		"""SCPI: [SOURce<HW>]:IQ:DPD:OUTPut:PEP \n
		Snippet: value: float = driver.source.iq.dpd.output.get_pep() \n
		Queries the measured values the before and after the enabled digital predistortion. \n
			:return: pep: float The query returns -1000 if the calculation is impossible or there are no measurements results available.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:DPD:OUTPut:PEP?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'OutputCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = OutputCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NetworkCls:
	"""Network commands group definition. 12 total commands, 12 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("network", core, parent)

	@property
	def avahi(self):
		"""avahi commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_avahi'):
			from .Avahi import AvahiCls
			self._avahi = AvahiCls(self._core, self._cmd_group)
		return self._avahi

	@property
	def ftp(self):
		"""ftp commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ftp'):
			from .Ftp import FtpCls
			self._ftp = FtpCls(self._core, self._cmd_group)
		return self._ftp

	@property
	def http(self):
		"""http commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_http'):
			from .Http import HttpCls
			self._http = HttpCls(self._core, self._cmd_group)
		return self._http

	@property
	def raw(self):
		"""raw commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_raw'):
			from .Raw import RawCls
			self._raw = RawCls(self._core, self._cmd_group)
		return self._raw

	@property
	def remSupport(self):
		"""remSupport commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_remSupport'):
			from .RemSupport import RemSupportCls
			self._remSupport = RemSupportCls(self._core, self._cmd_group)
		return self._remSupport

	@property
	def rpc(self):
		"""rpc commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_rpc'):
			from .Rpc import RpcCls
			self._rpc = RpcCls(self._core, self._cmd_group)
		return self._rpc

	@property
	def smb(self):
		"""smb commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_smb'):
			from .Smb import SmbCls
			self._smb = SmbCls(self._core, self._cmd_group)
		return self._smb

	@property
	def soe(self):
		"""soe commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_soe'):
			from .Soe import SoeCls
			self._soe = SoeCls(self._core, self._cmd_group)
		return self._soe

	@property
	def ssh(self):
		"""ssh commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ssh'):
			from .Ssh import SshCls
			self._ssh = SshCls(self._core, self._cmd_group)
		return self._ssh

	@property
	def swUpdate(self):
		"""swUpdate commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_swUpdate'):
			from .SwUpdate import SwUpdateCls
			self._swUpdate = SwUpdateCls(self._core, self._cmd_group)
		return self._swUpdate

	@property
	def vnc(self):
		"""vnc commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_vnc'):
			from .Vnc import VncCls
			self._vnc = VncCls(self._core, self._cmd_group)
		return self._vnc

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def clone(self) -> 'NetworkCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = NetworkCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DaylightSavingTimeCls:
	"""DaylightSavingTime commands group definition. 3 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("daylightSavingTime", core, parent)

	@property
	def rule(self):
		"""rule commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_rule'):
			from .Rule import RuleCls
			self._rule = RuleCls(self._core, self._cmd_group)
		return self._rule

	def get_mode(self) -> str:
		"""SCPI: SYSTem:TIME:DSTime:MODE \n
		Snippet: value: str = driver.system.time.daylightSavingTime.get_mode() \n
		No command help available \n
			:return: pseudo_string: No help available
		"""
		response = self._core.io.query_str('SYSTem:TIME:DSTime:MODE?')
		return trim_str_response(response)

	def set_mode(self, pseudo_string: str) -> None:
		"""SCPI: SYSTem:TIME:DSTime:MODE \n
		Snippet: driver.system.time.daylightSavingTime.set_mode(pseudo_string = '1') \n
		No command help available \n
			:param pseudo_string: No help available
		"""
		param = Conversions.value_to_quoted_str(pseudo_string)
		self._core.io.write(f'SYSTem:TIME:DSTime:MODE {param}')

	def clone(self) -> 'DaylightSavingTimeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DaylightSavingTimeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ClockCls:
	"""Clock commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("clock", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.SatNavClockMode:
		"""SCPI: [SOURce<HW>]:BB:XMRadio:SATellite:CLOCk:MODE \n
		Snippet: value: enums.SatNavClockMode = driver.source.bb.xmRadio.satellite.clock.get_mode() \n
		No command help available \n
			:return: mode: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:XMRadio:SATellite:CLOCk:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.SatNavClockMode)

	def set_mode(self, mode: enums.SatNavClockMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:XMRadio:SATellite:CLOCk:MODE \n
		Snippet: driver.source.bb.xmRadio.satellite.clock.set_mode(mode = enums.SatNavClockMode.MSYMbol) \n
		No command help available \n
			:param mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.SatNavClockMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:XMRadio:SATellite:CLOCk:MODE {param}')

	def get_multiplier(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:XMRadio:SATellite:CLOCk:MULTiplier \n
		Snippet: value: int = driver.source.bb.xmRadio.satellite.clock.get_multiplier() \n
		No command help available \n
			:return: multiplier: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:XMRadio:SATellite:CLOCk:MULTiplier?')
		return Conversions.str_to_int(response)

	def set_multiplier(self, multiplier: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:XMRadio:SATellite:CLOCk:MULTiplier \n
		Snippet: driver.source.bb.xmRadio.satellite.clock.set_multiplier(multiplier = 1) \n
		No command help available \n
			:param multiplier: No help available
		"""
		param = Conversions.decimal_value_to_str(multiplier)
		self._core.io.write(f'SOURce<HwInstance>:BB:XMRadio:SATellite:CLOCk:MULTiplier {param}')

	# noinspection PyTypeChecker
	def get_source(self) -> enums.ClockSourceB:
		"""SCPI: [SOURce<HW>]:BB:XMRadio:SATellite:CLOCk:SOURce \n
		Snippet: value: enums.ClockSourceB = driver.source.bb.xmRadio.satellite.clock.get_source() \n
		No command help available \n
			:return: source: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:XMRadio:SATellite:CLOCk:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.ClockSourceB)

	def set_source(self, source: enums.ClockSourceB) -> None:
		"""SCPI: [SOURce<HW>]:BB:XMRadio:SATellite:CLOCk:SOURce \n
		Snippet: driver.source.bb.xmRadio.satellite.clock.set_source(source = enums.ClockSourceB.AINTernal) \n
		No command help available \n
			:param source: No help available
		"""
		param = Conversions.enum_scalar_to_str(source, enums.ClockSourceB)
		self._core.io.write(f'SOURce<HwInstance>:BB:XMRadio:SATellite:CLOCk:SOURce {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class QuadratureCls:
	"""Quadrature commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("quadrature", core, parent)

	def get_angle(self) -> float:
		"""SCPI: [SOURce<HW>]:IQ:IMPairment:QUADrature:[ANGLe] \n
		Snippet: value: float = driver.source.iq.impairment.quadrature.get_angle() \n
		Sets the quadrature offset for the digital I/Q signal. \n
			:return: angle: float Range: -10 to 10
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:IMPairment:QUADrature:ANGLe?')
		return Conversions.str_to_float(response)

	def set_angle(self, angle: float) -> None:
		"""SCPI: [SOURce<HW>]:IQ:IMPairment:QUADrature:[ANGLe] \n
		Snippet: driver.source.iq.impairment.quadrature.set_angle(angle = 1.0) \n
		Sets the quadrature offset for the digital I/Q signal. \n
			:param angle: float Range: -10 to 10
		"""
		param = Conversions.decimal_value_to_str(angle)
		self._core.io.write(f'SOURce<HwInstance>:IQ:IMPairment:QUADrature:ANGLe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ExecuteCls:
	"""Execute commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("execute", core, parent)

	def set(self) -> None:
		"""SCPI: [SOURce<HW>]:BBIN:ALEVel:EXECute \n
		Snippet: driver.source.bbin.alevel.execute.set() \n
		This command starts measuring the input signal. The measurement estimates the crest factor and the peak power. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:BBIN:ALEVel:EXECute')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:BBIN:ALEVel:EXECute \n
		Snippet: driver.source.bbin.alevel.execute.set_with_opc() \n
		This command starts measuring the input signal. The measurement estimates the crest factor and the peak power. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSgt.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BBIN:ALEVel:EXECute', opc_timeout_ms)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BandwidthCls:
	"""Bandwidth commands group definition. 4 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bandwidth", core, parent)

	@property
	def coupling(self):
		"""coupling commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_coupling'):
			from .Coupling import CouplingCls
			self._coupling = CouplingCls(self._core, self._cmd_group)
		return self._coupling

	def get_noise(self) -> float:
		"""SCPI: [SOURce<HW>]:AWGN:BWIDth:NOISe \n
		Snippet: value: float = driver.source.awgn.bandwidth.get_noise() \n
		This command is available for modes In Additive Noise and Noise Only (SOUR:AWGN:MODE ADD|ONLY) modes, queries the real
		noise bandwidth. \n
			:return: noise: float Range: 0 to 200E6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AWGN:BWIDth:NOISe?')
		return Conversions.str_to_float(response)

	def get_ratio(self) -> float:
		"""SCPI: [SOURce<HW>]:AWGN:BWIDth:RATio \n
		Snippet: value: float = driver.source.awgn.bandwidth.get_ratio() \n
		In Additive Noise and Noise Only (SOUR:AWGN:MODE ADD|ONLY) modes, sets the ratio of minimum real noise bandwidth to
		system bandwidth. The overall bandwidth is calculated as follows and may not exceed the total bandwidth specified in the
		data sheet: Overall Bandwidth = System BW x Min Noise/System BW Ratio \n
			:return: ratio: float Range: 1 to Max
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AWGN:BWIDth:RATio?')
		return Conversions.str_to_float(response)

	def set_ratio(self, ratio: float) -> None:
		"""SCPI: [SOURce<HW>]:AWGN:BWIDth:RATio \n
		Snippet: driver.source.awgn.bandwidth.set_ratio(ratio = 1.0) \n
		In Additive Noise and Noise Only (SOUR:AWGN:MODE ADD|ONLY) modes, sets the ratio of minimum real noise bandwidth to
		system bandwidth. The overall bandwidth is calculated as follows and may not exceed the total bandwidth specified in the
		data sheet: Overall Bandwidth = System BW x Min Noise/System BW Ratio \n
			:param ratio: float Range: 1 to Max
		"""
		param = Conversions.decimal_value_to_str(ratio)
		self._core.io.write(f'SOURce<HwInstance>:AWGN:BWIDth:RATio {param}')

	def get_value(self) -> float:
		"""SCPI: [SOURce<HW>]:AWGN:BWIDth \n
		Snippet: value: float = driver.source.awgn.bandwidth.get_value() \n
		Sets the system bandwidth. The noise signal at the level which corresponds to the specified carrier/noise ratio is
		generated in the bandwidth specified here. This command is available for modes Additive Noise and Noise Only
		(SOUR:AWGN:MODE ADD|ONLY) . \n
			:return: bwidth: float Range: 1000 to depends on the installed options
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AWGN:BWIDth?')
		return Conversions.str_to_float(response)

	def set_value(self, bwidth: float) -> None:
		"""SCPI: [SOURce<HW>]:AWGN:BWIDth \n
		Snippet: driver.source.awgn.bandwidth.set_value(bwidth = 1.0) \n
		Sets the system bandwidth. The noise signal at the level which corresponds to the specified carrier/noise ratio is
		generated in the bandwidth specified here. This command is available for modes Additive Noise and Noise Only
		(SOUR:AWGN:MODE ADD|ONLY) . \n
			:param bwidth: float Range: 1000 to depends on the installed options
		"""
		param = Conversions.decimal_value_to_str(bwidth)
		self._core.io.write(f'SOURce<HwInstance>:AWGN:BWIDth {param}')

	def clone(self) -> 'BandwidthCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = BandwidthCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CfrCls:
	"""Cfr commands group definition. 14 total commands, 2 Subgroups, 12 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cfr", core, parent)

	@property
	def measure(self):
		"""measure commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_measure'):
			from .Measure import MeasureCls
			self._measure = MeasureCls(self._core, self._cmd_group)
		return self._measure

	@property
	def waveform(self):
		"""waveform commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_waveform'):
			from .Waveform import WaveformCls
			self._waveform = WaveformCls(self._core, self._cmd_group)
		return self._waveform

	# noinspection PyTypeChecker
	def get_algorithm(self) -> enums.CfrAlgo:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:ALGorithm \n
		Snippet: value: enums.CfrAlgo = driver.source.bb.arbitrary.cfr.get_algorithm() \n
		Displays the algorithm used for the crest factor reduction. The 'Clipping and filtering' algorithm performs a hard
		clipping. It is followed by a low pass filtering of the result in an iterative manner until the target crest factor is
		reached. You can define the settings of the filter that is used for the calculation. \n
			:return: arb_cfr_algorithm: CLFiltering
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:CFR:ALGorithm?')
		return Conversions.str_to_scalar_enum(response, enums.CfrAlgo)

	def set_algorithm(self, arb_cfr_algorithm: enums.CfrAlgo) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:ALGorithm \n
		Snippet: driver.source.bb.arbitrary.cfr.set_algorithm(arb_cfr_algorithm = enums.CfrAlgo.CLFiltering) \n
		Displays the algorithm used for the crest factor reduction. The 'Clipping and filtering' algorithm performs a hard
		clipping. It is followed by a low pass filtering of the result in an iterative manner until the target crest factor is
		reached. You can define the settings of the filter that is used for the calculation. \n
			:param arb_cfr_algorithm: CLFiltering
		"""
		param = Conversions.enum_scalar_to_str(arb_cfr_algorithm, enums.CfrAlgo)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:CFR:ALGorithm {param}')

	def get_cspacing(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:CSPacing \n
		Snippet: value: float = driver.source.bb.arbitrary.cfr.get_cspacing() \n
		Sets the channel spacing, if [:SOURce<hw>]:BB:ARBitrary:CFR:FILTer is set to SIMPle. \n
			:return: arb_cfr_chan_spac: float Range: 0 to depends on the sample rate of the loaded file
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:CFR:CSPacing?')
		return Conversions.str_to_float(response)

	def set_cspacing(self, arb_cfr_chan_spac: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:CSPacing \n
		Snippet: driver.source.bb.arbitrary.cfr.set_cspacing(arb_cfr_chan_spac = 1.0) \n
		Sets the channel spacing, if [:SOURce<hw>]:BB:ARBitrary:CFR:FILTer is set to SIMPle. \n
			:param arb_cfr_chan_spac: float Range: 0 to depends on the sample rate of the loaded file
		"""
		param = Conversions.decimal_value_to_str(arb_cfr_chan_spac)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:CFR:CSPacing {param}')

	def get_dcfdelta(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:DCFDelta \n
		Snippet: value: float = driver.source.bb.arbitrary.cfr.get_dcfdelta() \n
		Sets the value difference by which you want to change your crest factor. \n
			:return: arb_cfr_dcf_delta: float Range: -20 to 0
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:CFR:DCFDelta?')
		return Conversions.str_to_float(response)

	def set_dcfdelta(self, arb_cfr_dcf_delta: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:DCFDelta \n
		Snippet: driver.source.bb.arbitrary.cfr.set_dcfdelta(arb_cfr_dcf_delta = 1.0) \n
		Sets the value difference by which you want to change your crest factor. \n
			:param arb_cfr_dcf_delta: float Range: -20 to 0
		"""
		param = Conversions.decimal_value_to_str(arb_cfr_dcf_delta)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:CFR:DCFDelta {param}')

	# noinspection PyTypeChecker
	def get_filter_py(self) -> enums.CfrFiltMode:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:FILTer \n
		Snippet: value: enums.CfrFiltMode = driver.source.bb.arbitrary.cfr.get_filter_py() \n
		Selects which filter mode is used for the filtering. \n
			:return: arb_cfr_filter_mod: SIMPle| ENHanced
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:CFR:FILTer?')
		return Conversions.str_to_scalar_enum(response, enums.CfrFiltMode)

	def set_filter_py(self, arb_cfr_filter_mod: enums.CfrFiltMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:FILTer \n
		Snippet: driver.source.bb.arbitrary.cfr.set_filter_py(arb_cfr_filter_mod = enums.CfrFiltMode.ENHanced) \n
		Selects which filter mode is used for the filtering. \n
			:param arb_cfr_filter_mod: SIMPle| ENHanced
		"""
		param = Conversions.enum_scalar_to_str(arb_cfr_filter_mod, enums.CfrFiltMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:CFR:FILTer {param}')

	def get_forder(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:FORDer \n
		Snippet: value: int = driver.source.bb.arbitrary.cfr.get_forder() \n
		Sets the maximum filter order, if [:SOURce<hw>]:BB:ARBitrary:CFR:FILTer is set to ENHanced. \n
			:return: arb_cfr_max_file_order: integer Range: 0 to 300
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:CFR:FORDer?')
		return Conversions.str_to_int(response)

	def set_forder(self, arb_cfr_max_file_order: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:FORDer \n
		Snippet: driver.source.bb.arbitrary.cfr.set_forder(arb_cfr_max_file_order = 1) \n
		Sets the maximum filter order, if [:SOURce<hw>]:BB:ARBitrary:CFR:FILTer is set to ENHanced. \n
			:param arb_cfr_max_file_order: integer Range: 0 to 300
		"""
		param = Conversions.decimal_value_to_str(arb_cfr_max_file_order)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:CFR:FORDer {param}')

	def get_iterations(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:ITERations \n
		Snippet: value: int = driver.source.bb.arbitrary.cfr.get_iterations() \n
		Sets the number of iterations that are used for calculating the resulting crest factor. The iteration process is stopped
		when the desired crest factor delta is achieved by 0.1 dB. \n
			:return: arb_cfr_max_iter: integer Range: 1 to 10
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:CFR:ITERations?')
		return Conversions.str_to_int(response)

	def set_iterations(self, arb_cfr_max_iter: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:ITERations \n
		Snippet: driver.source.bb.arbitrary.cfr.set_iterations(arb_cfr_max_iter = 1) \n
		Sets the number of iterations that are used for calculating the resulting crest factor. The iteration process is stopped
		when the desired crest factor delta is achieved by 0.1 dB. \n
			:param arb_cfr_max_iter: integer Range: 1 to 10
		"""
		param = Conversions.decimal_value_to_str(arb_cfr_max_iter)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:CFR:ITERations {param}')

	def get_oc_factor(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:OCFactor \n
		Snippet: value: float = driver.source.bb.arbitrary.cfr.get_oc_factor() \n
		Queries the original crest factor of the waveform after the calculation of the resulting crest factor is completed. The
		original crest factor is calculated as an average over the whole waveform, including any idle periods that might be
		present in TDD waveforms. \n
			:return: arb_cfro_crest_factor: float Range: 1 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:CFR:OCFactor?')
		return Conversions.str_to_float(response)

	def get_pfreq(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:PFReq \n
		Snippet: value: float = driver.source.bb.arbitrary.cfr.get_pfreq() \n
		Sets the passband frequency, if [:SOURce<hw>]:BB:ARBitrary:CFR:FILTer is set to ENHanced. Frequency components lower than
		the passband frequency are passed through unfiltered. \n
			:return: arb_cfr_pass_band_freq: float Range: 0 to depends on the sample rate of the loaded file
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:CFR:PFReq?')
		return Conversions.str_to_float(response)

	def set_pfreq(self, arb_cfr_pass_band_freq: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:PFReq \n
		Snippet: driver.source.bb.arbitrary.cfr.set_pfreq(arb_cfr_pass_band_freq = 1.0) \n
		Sets the passband frequency, if [:SOURce<hw>]:BB:ARBitrary:CFR:FILTer is set to ENHanced. Frequency components lower than
		the passband frequency are passed through unfiltered. \n
			:param arb_cfr_pass_band_freq: float Range: 0 to depends on the sample rate of the loaded file
		"""
		param = Conversions.decimal_value_to_str(arb_cfr_pass_band_freq)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:CFR:PFReq {param}')

	def get_rc_factor(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:RCFactor \n
		Snippet: value: float = driver.source.bb.arbitrary.cfr.get_rc_factor() \n
		Queries the resulting crest factor of the waveform after the calculations are completed. The resulting crest factor is
		calculated as an average over the whole waveform, including any idle periods that might be present in TDD waveforms. \n
			:return: arb_cfr_res_crest_factor: float Range: 1 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:CFR:RCFactor?')
		return Conversions.str_to_float(response)

	def get_sbandwidth(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:SBANdwidth \n
		Snippet: value: float = driver.source.bb.arbitrary.cfr.get_sbandwidth() \n
		Sets the signal bandwidth, if [:SOURce<hw>]:BB:ARBitrary:CFR:FILTer is set to SIMPle. The value of the signal bandwidth
		should not be higher than the channel spacing ([:SOURce<hw>]:BB:ARBitrary:CFR:CSPacing) . \n
			:return: arb_cfr_signal_bw: float Range: 0 to depends on the sample rate of the loaded file
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:CFR:SBANdwidth?')
		return Conversions.str_to_float(response)

	def set_sbandwidth(self, arb_cfr_signal_bw: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:SBANdwidth \n
		Snippet: driver.source.bb.arbitrary.cfr.set_sbandwidth(arb_cfr_signal_bw = 1.0) \n
		Sets the signal bandwidth, if [:SOURce<hw>]:BB:ARBitrary:CFR:FILTer is set to SIMPle. The value of the signal bandwidth
		should not be higher than the channel spacing ([:SOURce<hw>]:BB:ARBitrary:CFR:CSPacing) . \n
			:param arb_cfr_signal_bw: float Range: 0 to depends on the sample rate of the loaded file
		"""
		param = Conversions.decimal_value_to_str(arb_cfr_signal_bw)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:CFR:SBANdwidth {param}')

	def get_sfreq(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:SFReq \n
		Snippet: value: float = driver.source.bb.arbitrary.cfr.get_sfreq() \n
		Sets the stopband frequency of the filter, if [:SOURce<hw>]:BB:ARBitrary:CFR:FILTer is set to ENHanced.
		Frequency components higher than the stopband frequency are filtered out by the lowpass filter. \n
			:return: arb_cfr_stop_band_freq: float Range: 0 to depends on the sample rate of the loaded file
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:CFR:SFReq?')
		return Conversions.str_to_float(response)

	def set_sfreq(self, arb_cfr_stop_band_freq: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:SFReq \n
		Snippet: driver.source.bb.arbitrary.cfr.set_sfreq(arb_cfr_stop_band_freq = 1.0) \n
		Sets the stopband frequency of the filter, if [:SOURce<hw>]:BB:ARBitrary:CFR:FILTer is set to ENHanced.
		Frequency components higher than the stopband frequency are filtered out by the lowpass filter. \n
			:param arb_cfr_stop_band_freq: float Range: 0 to depends on the sample rate of the loaded file
		"""
		param = Conversions.decimal_value_to_str(arb_cfr_stop_band_freq)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:CFR:SFReq {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:[STATe] \n
		Snippet: value: bool = driver.source.bb.arbitrary.cfr.get_state() \n
		Enables the crest factor reduction calculation. \n
			:return: arb_cfr_state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:CFR:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arb_cfr_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:CFR:[STATe] \n
		Snippet: driver.source.bb.arbitrary.cfr.set_state(arb_cfr_state = False) \n
		Enables the crest factor reduction calculation. \n
			:param arb_cfr_state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(arb_cfr_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:CFR:STATe {param}')

	def clone(self) -> 'CfrCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CfrCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BbinCls:
	"""Bbin commands group definition. 23 total commands, 7 Subgroups, 10 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bbin", core, parent)

	@property
	def alevel(self):
		"""alevel commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_alevel'):
			from .Alevel import AlevelCls
			self._alevel = AlevelCls(self._core, self._cmd_group)
		return self._alevel

	@property
	def digital(self):
		"""digital commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_digital'):
			from .Digital import DigitalCls
			self._digital = DigitalCls(self._core, self._cmd_group)
		return self._digital

	@property
	def iqswap(self):
		"""iqswap commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_iqswap'):
			from .Iqswap import IqswapCls
			self._iqswap = IqswapCls(self._core, self._cmd_group)
		return self._iqswap

	@property
	def offset(self):
		"""offset commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_offset'):
			from .Offset import OffsetCls
			self._offset = OffsetCls(self._core, self._cmd_group)
		return self._offset

	@property
	def oload(self):
		"""oload commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_oload'):
			from .Oload import OloadCls
			self._oload = OloadCls(self._core, self._cmd_group)
		return self._oload

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRateCls
			self._symbolRate = SymbolRateCls(self._core, self._cmd_group)
		return self._symbolRate

	def get_cdevice(self) -> str:
		"""SCPI: [SOURce<HW>]:BBIN:CDEVice \n
		Snippet: value: str = driver.source.bbin.get_cdevice() \n
		Digital Input only. Indicates the ID of an externally connected R&S Instrument or R&S Device. \n
			:return: cdevice: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BBIN:CDEVice?')
		return trim_str_response(response)

	def get_cfactor(self) -> float:
		"""SCPI: [SOURce<HW>]:BBIN:CFACtor \n
		Snippet: value: float = driver.source.bbin.get_cfactor() \n
		This command enters the crest factor of the external baseband signal. \n
			:return: cfactor: float Range: 0 to 30, Unit: dB
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BBIN:CFACtor?')
		return Conversions.str_to_float(response)

	def set_cfactor(self, cfactor: float) -> None:
		"""SCPI: [SOURce<HW>]:BBIN:CFACtor \n
		Snippet: driver.source.bbin.set_cfactor(cfactor = 1.0) \n
		This command enters the crest factor of the external baseband signal. \n
			:param cfactor: float Range: 0 to 30, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(cfactor)
		self._core.io.write(f'SOURce<HwInstance>:BBIN:CFACtor {param}')

	def get_foffset(self) -> float:
		"""SCPI: [SOURce<HW>]:BBIN:FOFFset \n
		Snippet: value: float = driver.source.bbin.get_foffset() \n
		Enters the frequency offset for the external baseband signal. The complex I/Q bandwidth of the shifted useful signal must
		not exceed the total available baseband bandwidth (see data sheet) . \n
			:return: foffset: float Range: -40E6 to 40E6, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BBIN:FOFFset?')
		return Conversions.str_to_float(response)

	def set_foffset(self, foffset: float) -> None:
		"""SCPI: [SOURce<HW>]:BBIN:FOFFset \n
		Snippet: driver.source.bbin.set_foffset(foffset = 1.0) \n
		Enters the frequency offset for the external baseband signal. The complex I/Q bandwidth of the shifted useful signal must
		not exceed the total available baseband bandwidth (see data sheet) . \n
			:param foffset: float Range: -40E6 to 40E6, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(foffset)
		self._core.io.write(f'SOURce<HwInstance>:BBIN:FOFFset {param}')

	def get_gimbalance(self) -> float:
		"""SCPI: [SOURce<HW>]:BBIN:GIMBalance \n
		Snippet: value: float = driver.source.bbin.get_gimbalance() \n
		This command enters a gain to the Q component of the external baseband signal. \n
			:return: gimbalance: float Range: -3 to 3, Unit: dB
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BBIN:GIMBalance?')
		return Conversions.str_to_float(response)

	def set_gimbalance(self, gimbalance: float) -> None:
		"""SCPI: [SOURce<HW>]:BBIN:GIMBalance \n
		Snippet: driver.source.bbin.set_gimbalance(gimbalance = 1.0) \n
		This command enters a gain to the Q component of the external baseband signal. \n
			:param gimbalance: float Range: -3 to 3, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(gimbalance)
		self._core.io.write(f'SOURce<HwInstance>:BBIN:GIMBalance {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.AnalogDigitalMode:
		"""SCPI: [SOURce<HW>]:BBIN:MODE \n
		Snippet: value: enums.AnalogDigitalMode = driver.source.bbin.get_mode() \n
		This command selects the external input signal mode for the 'Baseband In' block. \n
			:return: mode: ANALog| DIGital ANALog The external analog baseband signal is supplied via the inputs I and Q. DIGItal The external digital baseband signal is fed into the signal path via the 'Digital Input' connector. The internal signal processing is based on a sample rate of 100 MHz. Input signals with a sample rate less than 100 MHz are upsampled. The sample rate can be estimated or defined by the user in the appropriate entry fields.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BBIN:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AnalogDigitalMode)

	def set_mode(self, mode: enums.AnalogDigitalMode) -> None:
		"""SCPI: [SOURce<HW>]:BBIN:MODE \n
		Snippet: driver.source.bbin.set_mode(mode = enums.AnalogDigitalMode.ANALog) \n
		This command selects the external input signal mode for the 'Baseband In' block. \n
			:param mode: ANALog| DIGital ANALog The external analog baseband signal is supplied via the inputs I and Q. DIGItal The external digital baseband signal is fed into the signal path via the 'Digital Input' connector. The internal signal processing is based on a sample rate of 100 MHz. Input signals with a sample rate less than 100 MHz are upsampled. The sample rate can be estimated or defined by the user in the appropriate entry fields.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.AnalogDigitalMode)
		self._core.io.write(f'SOURce<HwInstance>:BBIN:MODE {param}')

	def get_mperiod(self) -> int:
		"""SCPI: [SOURce<HW>]:BBIN:MPERiod \n
		Snippet: value: int = driver.source.bbin.get_mperiod() \n
		Sets the recording duration for measuring the baseband input signal by Auto Level Set. \n
			:return: mperiod: integer Range: 1 to 32, Unit: s
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BBIN:MPERiod?')
		return Conversions.str_to_int(response)

	def set_mperiod(self, mperiod: int) -> None:
		"""SCPI: [SOURce<HW>]:BBIN:MPERiod \n
		Snippet: driver.source.bbin.set_mperiod(mperiod = 1) \n
		Sets the recording duration for measuring the baseband input signal by Auto Level Set. \n
			:param mperiod: integer Range: 1 to 32, Unit: s
		"""
		param = Conversions.decimal_value_to_str(mperiod)
		self._core.io.write(f'SOURce<HwInstance>:BBIN:MPERiod {param}')

	def get_odelay(self) -> float:
		"""SCPI: [SOURce<HW>]:BBIN:ODELay \n
		Snippet: value: float = driver.source.bbin.get_odelay() \n
		Seds the output delay of the external baseband signal. \n
			:return: delay: float Range: 0 to 1
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BBIN:ODELay?')
		return Conversions.str_to_float(response)

	def set_odelay(self, delay: float) -> None:
		"""SCPI: [SOURce<HW>]:BBIN:ODELay \n
		Snippet: driver.source.bbin.set_odelay(delay = 1.0) \n
		Seds the output delay of the external baseband signal. \n
			:param delay: float Range: 0 to 1
		"""
		param = Conversions.decimal_value_to_str(delay)
		self._core.io.write(f'SOURce<HwInstance>:BBIN:ODELay {param}')

	def get_pgain(self) -> float:
		"""SCPI: [SOURce<HW>]:BBIN:PGAin \n
		Snippet: value: float = driver.source.bbin.get_pgain() \n
		This command enters the relative gain for the external baseband signal compared with the signals of the other baseband
		sources. The actual gain of the different baseband signals depends not only on the path gain setting but also on the
		signal characteristics such as the crest factor and on the number of used sources. used and on the total RF output power.
		The gain affects the signal on the 'Baseband' In block output. \n
			:return: pgain: float Range: -50 to 50, Unit: dB
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BBIN:PGAin?')
		return Conversions.str_to_float(response)

	def set_pgain(self, pgain: float) -> None:
		"""SCPI: [SOURce<HW>]:BBIN:PGAin \n
		Snippet: driver.source.bbin.set_pgain(pgain = 1.0) \n
		This command enters the relative gain for the external baseband signal compared with the signals of the other baseband
		sources. The actual gain of the different baseband signals depends not only on the path gain setting but also on the
		signal characteristics such as the crest factor and on the number of used sources. used and on the total RF output power.
		The gain affects the signal on the 'Baseband' In block output. \n
			:param pgain: float Range: -50 to 50, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(pgain)
		self._core.io.write(f'SOURce<HwInstance>:BBIN:PGAin {param}')

	def get_skew(self) -> float:
		"""SCPI: [SOURce<HW>]:BBIN:SKEW \n
		Snippet: value: float = driver.source.bbin.get_skew() \n
		This command determines the delay between Q and I channel. Positive values represent a delay for Q versus I. \n
			:return: skew: float Range: -1E-9 to 1E-9, Unit: s
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BBIN:SKEW?')
		return Conversions.str_to_float(response)

	def set_skew(self, skew: float) -> None:
		"""SCPI: [SOURce<HW>]:BBIN:SKEW \n
		Snippet: driver.source.bbin.set_skew(skew = 1.0) \n
		This command determines the delay between Q and I channel. Positive values represent a delay for Q versus I. \n
			:param skew: float Range: -1E-9 to 1E-9, Unit: s
		"""
		param = Conversions.decimal_value_to_str(skew)
		self._core.io.write(f'SOURce<HwInstance>:BBIN:SKEW {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BBIN:STATe \n
		Snippet: value: bool = driver.source.bbin.get_state() \n
		This command switches the feeding of an external analog signal into the signal path on/off. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BBIN:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BBIN:STATe \n
		Snippet: driver.source.bbin.set_state(state = False) \n
		This command switches the feeding of an external analog signal into the signal path on/off. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BBIN:STATe {param}')

	def clone(self) -> 'BbinCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = BbinCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AngleCls:
	"""Angle commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("angle", core, parent)

	def set(self, angle: float, iqConnector=repcap.IqConnector.Default) -> None:
		"""SCPI: [SOURce]:BB:IMPairment:IQOutput<CH>:QUADrature:[ANGLe] \n
		Snippet: driver.source.bb.impairment.iqOutput.quadrature.angle.set(angle = 1.0, iqConnector = repcap.IqConnector.Default) \n
		Sets the quadrature offset. A positive quadrature offset results in a phase angle greater than 90 degrees.
			INTRO_CMD_HELP: The suffix <ch> has the following values: \n
			- <ch>= 0: I/Q Analog Outputs
			- <ch>= 1: I/Q Modulator Digital Impairments \n
			:param angle: float Range: -10 to 10
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'IqOutput')
		"""
		param = Conversions.decimal_value_to_str(angle)
		iqConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		self._core.io.write(f'SOURce:BB:IMPairment:IQOutput{iqConnector_cmd_val}:QUADrature:ANGLe {param}')

	def get(self, iqConnector=repcap.IqConnector.Default) -> float:
		"""SCPI: [SOURce]:BB:IMPairment:IQOutput<CH>:QUADrature:[ANGLe] \n
		Snippet: value: float = driver.source.bb.impairment.iqOutput.quadrature.angle.get(iqConnector = repcap.IqConnector.Default) \n
		Sets the quadrature offset. A positive quadrature offset results in a phase angle greater than 90 degrees.
			INTRO_CMD_HELP: The suffix <ch> has the following values: \n
			- <ch>= 0: I/Q Analog Outputs
			- <ch>= 1: I/Q Modulator Digital Impairments \n
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'IqOutput')
			:return: angle: float Range: -10 to 10"""
		iqConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		response = self._core.io.query_str(f'SOURce:BB:IMPairment:IQOutput{iqConnector_cmd_val}:QUADrature:ANGLe?')
		return Conversions.str_to_float(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	def get_sw_points(self) -> str:
		"""SCPI: CALibration:FREQuency:SWPoints \n
		Snippet: value: str = driver.calibration.frequency.get_sw_points() \n
		No command help available \n
			:return: freq_switch_point: No help available
		"""
		response = self._core.io.query_str('CALibration:FREQuency:SWPoints?')
		return trim_str_response(response)

	def set_sw_points(self, freq_switch_point: str) -> None:
		"""SCPI: CALibration:FREQuency:SWPoints \n
		Snippet: driver.calibration.frequency.set_sw_points(freq_switch_point = '1') \n
		No command help available \n
			:param freq_switch_point: No help available
		"""
		param = Conversions.value_to_quoted_str(freq_switch_point)
		self._core.io.write(f'CALibration:FREQuency:SWPoints {param}')

	def get_temperature(self) -> str:
		"""SCPI: CALibration:FREQuency:TEMPerature \n
		Snippet: value: str = driver.calibration.frequency.get_temperature() \n
		Queries the delta temperature since the last performed adjustment. \n
			:return: temperature: string
		"""
		response = self._core.io.query_str('CALibration:FREQuency:TEMPerature?')
		return trim_str_response(response)

	def get_measure(self) -> bool:
		"""SCPI: CALibration:FREQuency:[MEASure] \n
		Snippet: value: bool = driver.calibration.frequency.get_measure() \n
		Performs all adjustments which affect the frequency. \n
			:return: synthesis: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('CALibration:FREQuency:MEASure?')
		return Conversions.str_to_bool(response)



import pathlib
from setuptools import setup, find_packages

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.rst").read_text()

# This call to setup() does all the work
setup(
    name="RsSgt",
    version="4.90.109",
    description="SGT100A SIGMA Vector Signal Generator Remote-control module",
    long_description=README,
    long_description_content_type="text/x-rst",
    author="Rohde & Schwarz GmbH & Co. KG",
    copyright="Copyright © Rohde & Schwarz GmbH & Co. KG 2022",
    license="MIT",
    classifiers=['License :: OSI Approved :: MIT License',
                 'Intended Audience :: Developers',
                 'Operating System :: Microsoft :: Windows',
                 'Operating System :: POSIX :: Linux',
                 'Operating System :: MacOS :: MacOS X',
                 'Programming Language :: Python',
                 'Programming Language :: Python :: 3',
                 'Programming Language :: Python :: 3.6',
                 'Programming Language :: Python :: 3.7',
                 'Programming Language :: Python :: 3.8',
                 'Programming Language :: Python :: 3.9',
                 'Programming Language :: Python :: 3.10'
                ],
    packages=(find_packages(include=['RsSgt', 'RsSgt.*'])),
    install_requires=['PyVisa>=1.11.3'],
    python_requires='>=3.6'
)


"""See the docstring for the InstrumentSettings class."""

from enum import Enum
from enum import Flag
from re import search
from typing import List

from . import InstrumentOptions as Opts
from . import Conversions as Conv
from .ScpiLogger import LoggingMode
from .Utilities import parse_token_to_key_and_value, trim_str_response


class InstrViClearMode(Flag):
	"""Mode for executing viClear() method."""
	disabled = 0x00
	ignore_error = 0x01
	execute_on_all = 0x02
	execute_on_socket = 0x04
	execute_on_serial = 0x08
	execute_on_usb = 0x10
	execute_on_gpib = 0x20
	execute_on_tcpvxi = 0x40


class WaitForOpcMode(Enum):
	"""Mode that is used for OPC-sync commands/queries"""
	stb_poll = 1
	stb_poll_slow = 2
	stb_poll_superslow = 3
	opc_query = 4


class InstrumentSettings(object):
	"""Defines settings of the instrument session."""

	def __init__(
			self,
			viclear_exe_mode: InstrViClearMode,
			idn_model_full_name: bool,
			write_delay: int,
			read_delay: int,
			io_segment_size: int,
			opc_wait_mode: WaitForOpcMode,
			opc_timeout: int,
			visa_timeout: int,
			self_test_timeout: int,
			instr_options_parse_mode: Opts.ParseMode,
			bin_float_numbers_format: Conv.BinFloatFormat,
			bin_int_numbers_format: Conv.BinIntFormat,
			opc_query_after_write: bool,
			logging_mode: LoggingMode):

		self.viclear_exe_mode = viclear_exe_mode
		self.idn_model_full_name = idn_model_full_name
		self.write_delay = write_delay
		self.read_delay = read_delay
		self.io_segment_size = io_segment_size
		self.opc_wait_mode = opc_wait_mode
		self.opc_timeout = opc_timeout
		self.visa_timeout = visa_timeout
		self.selftest_timeout = self_test_timeout
		self.instr_options_parse_mode = instr_options_parse_mode
		self.bin_float_numbers_format = bin_float_numbers_format
		self.bin_int_numbers_format = bin_int_numbers_format
		self.opc_query_after_write = opc_query_after_write

		self.logging_mode = logging_mode
		self.logging_name = None
		self.log_to_global_target = False
		self.log_to_console = False
		self.log_to_udp = False
		self.log_udp_port = 49200

		self.assure_write_with_tc = False
		self.term_char = '\n'
		self.encoding = 'charmap'
		self.add_term_char_to_write_bin_block = False
		self.open_timeout = 0
		self.exclusive_lock = False
		self.vxi_capable = True

		self.cmd_idn = '*IDN?'
		self.cmd_reset = '*RST'
		self.skip_status_system_setting = False
		self.skip_clear_status = False
		self.stb_in_error_check = True
		self.instr_status_check = False
		self.disable_opc_query = False

		self.visa_select = None
		self._last_settings = None

		# Instrument object settings
		self.instrument_status_check = None
		self.instrument_simulation_idn_string = None

		# Core object settings
		self.simulating = False
		self.supported_instr_models: List[str] = []
		self.supported_idn_patterns: List[str] = []

	def _get_driversetup_item(self, name: str) -> str:
		"""Looks for a token that either has the name with prefix DRIVERSETUP_ or no prefix.
		Example: Keynames DRIVERSETUP_WRITEDELAY and WRITEDELAY are equivalent.
		If both keynames are present, the one with DRIVERSETUP_ has priority."""
		name = name.upper()
		value = self._last_settings.get(f'DRIVERSETUP_{name}')
		if value is None:
			value = self._last_settings.get(name)
		return value

	def _get_item(self, name: str) -> str:
		"""Returns a token value with the keyname name (case-insensitive) from the last settings dictionary.
		If the keyname does not exist, the method returns None."""
		value = self._last_settings.get(name.upper())
		return value

	# noinspection PyMethodMayBeStatic
	def _parse_init_settings_string(self, text: str) -> dict:
		"""Parses init string to a dictionary of settings: name -> value."""
		tokens = {}
		if not text:
			return tokens

		# Text enclosed in single brackets '' must have the commas escaped
		literal_pattern = r"'([^']+)'"
		while True:
			# literal loop
			m = search(literal_pattern, text)
			if not m:
				break
			lit_part = '"' + m.group(1).replace(',', '<COMMA_ESC>') + '"'
			text = text.replace(m.group(0), lit_part)

		# Remove all the class-options enclosed by round brackets e.g. "<groupName>=(<groupTokens>)"
		group_pattern = r'(\w+)\s*=\s*\(([^\)]*)\)'
		# Match class-settings, add them as separate keys with groupName_Key
		while True:
			# Group loop
			m = search(group_pattern, text)
			if not m:
				break
			text = text.replace(m.group(0), '')
			group_name = m.group(1).upper()
			group_tokens = m.group(2).strip().split(',')
			for token in group_tokens:
				key, value = parse_token_to_key_and_value(token)
				if value:
					tokens[f'{group_name}_{key.upper()}'] = value

		# All groups are removed from the text, now we can use splitting on commas and remove white-space-only elements
		for token in text.split(','):
			key, value = parse_token_to_key_and_value(token.replace('<COMMA_ESC>', ','))
			if value:
				tokens[key.upper()] = value
		return tokens

	def apply_option_settings(self, text: str or None) -> None:
		"""Takes options from the settings dictionary and applies them to the InstrumentSettings class properties."""
		if not text:
			return
		if len(text) == 0:
			return
		self._last_settings = self._parse_init_settings_string(text)

		value = self._get_item('SelectVisa')
		if value:
			self.visa_select = value

		value = self._get_driversetup_item('WriteDelay')
		if value:
			self.write_delay = Conv.str_to_int(value)

		value = self._get_driversetup_item('ReadDelay')
		if value is not None:
			self.read_delay = Conv.str_to_int(value)

		value = self._get_driversetup_item('OpcWaitMode')
		if value:
			value = value.upper()
			if value == 'STBPOLLING':
				self.opc_wait_mode = WaitForOpcMode.stb_poll
			elif value == 'STBPOLLINGSLOW':
				self.opc_wait_mode = WaitForOpcMode.stb_poll_slow
			elif value == 'STBPOLLINGSUPERSLOW':
				self.opc_wait_mode = WaitForOpcMode.stb_poll_superslow
			elif value == 'OPCQUERY':
				self.opc_wait_mode = WaitForOpcMode.opc_query
			else:
				raise ValueError(
					f"Unknown value in InitWithOptions string DriverSetup key 'WaitForOPC'. Value '{value}' is not recognized. "
					"Valid values: 'StbPolling', 'StbPollingSlow', 'StbPollingSuperSlow', 'OpcQuery'")

		value = self._get_driversetup_item('AddTermCharToWriteBinBlock')
		if value:
			self.add_term_char_to_write_bin_block = Conv.str_to_bool(value)

		value = self._get_driversetup_item('OpenTimeout')
		if value:
			self.open_timeout = Conv.str_to_int(value)

		value = self._get_driversetup_item('ExclusiveLock')
		if value:
			self.exclusive_lock = Conv.str_to_bool(value)

		value = self._get_driversetup_item('VxiCapable')
		if value:
			self.vxi_capable = Conv.str_to_bool(value)

		# Obsolete, use the AssureWriteWithTermChar
		value = self._get_driversetup_item('AssureWriteWithLf')
		if not value:
			value = self._get_driversetup_item('AssureWriteWithTermChar')
		if value:
			self.assure_write_with_tc = Conv.str_to_bool(value)

		# Obsolete, use the DataChunkSize
		value = self._get_driversetup_item('IoSegmentSize')
		if not value:
			value = self._get_driversetup_item('DataChunkSize')
		if value:
			self.io_segment_size = Conv.str_to_int(value)

		value = self._get_driversetup_item('TerminationCharacter')
		if value:
			val_lc = value.lower()
			if value == '\\r' or val_lc == 'cr':
				self.term_char = '\r'
			elif value == '\\n' or val_lc == 'lf':
				self.term_char = '\n'
			elif value == '\\t' or val_lc == 'tab':
				self.term_char = '\t'
			elif value == '\\0' or val_lc == 'null':
				self.term_char = '\0'
			elif val_lc.startswith("0x") and len(val_lc) >= 4:
				self.term_char = chr(int(value[2:], 16))
			else:
				self.term_char = value

		value = self._get_driversetup_item('Encoding')
		if value:
			self.encoding = value

		value = self._get_driversetup_item('OpcTimeout')
		if value:
			self.opc_timeout = Conv.str_to_int(value)

		value = self._get_driversetup_item('VisaTimeout')
		if value:
			self.visa_timeout = Conv.str_to_int(value)

		value = self._get_driversetup_item('ViClearExeMode')
		if value:
			enum_value = Conv.str_to_simple_scalar_enum(value, InstrViClearMode, case_sensitive=False, ignore_underscores=True)
			if enum_value is None:
				try:
					enum_value = InstrViClearMode(Conv.str_to_int(value))
				except ValueError:
					raise ValueError(
						f"Unknown value in InitWithOptions string DriverSetup key 'ViClearExeMode'. Value '{value}' is not recognized. "
						f"Valid values: ExecuteOnAll, Disabled, IgnoreError or integer bit-wise value.")
			self.viclear_exe_mode = enum_value

		value = self._get_driversetup_item('OpcQueryAfterWrite')
		if value:
			self.opc_query_after_write = Conv.str_to_bool(value)

		value = self._get_driversetup_item('StbInErrorCheck')
		if value:
			self.stb_in_error_check = Conv.str_to_bool(value)

		value = self._get_driversetup_item('DisableOpcQuery')
		if value:
			self.disable_opc_query = Conv.str_to_bool(value)

		value = self._get_driversetup_item('LoggingMode')
		if value:
			enum_value = Conv.str_to_simple_scalar_enum(value, LoggingMode, case_sensitive=False)
			if not enum_value:
				raise ValueError(
					f"Unknown value in InitWithOptions string 'options', key 'LoggingMode'. Value '{value}' is not recognized. "
					f"Valid values: {', '.join([x.name for x in LoggingMode])}")
			self.logging_mode = enum_value

		# Logging
		value = self._get_driversetup_item('LoggingName')
		if value:
			self.logging_name = value

		value = self._get_driversetup_item('LogToGlobalTarget')
		if value:
			self.log_to_global_target = Conv.str_to_bool(value)

		value = self._get_driversetup_item('LoggingToConsole')
		if value:
			self.log_to_console = Conv.str_to_bool(value)

		value = self._get_driversetup_item('LoggingToUdp')
		if value:
			self.log_to_udp = Conv.str_to_bool(value)

		value = self._get_driversetup_item('LoggingUdpPort')
		if value:
			self.log_udp_port = Conv.str_to_int(value)

		# Others
		value = self._get_driversetup_item('CmdIdn')
		if value:
			self.cmd_idn = value

		value = self._get_driversetup_item('CmdReset')
		if value:
			self.cmd_reset = value

		value = self._get_driversetup_item('SkipStatusSystemSettings')
		if value:
			self.skip_status_system_setting = Conv.str_to_bool(value)

		value = self._get_driversetup_item('SkipClearStatus')
		if value:
			self.skip_clear_status = Conv.str_to_bool(value)

		value = self._get_driversetup_item('QueryOpt')
		if value:
			enum_value = Conv.str_to_simple_scalar_enum(value, Opts.ParseMode, case_sensitive=False)
			if not enum_value:
				raise ValueError(
					f"Unknown value in InitWithOptions string 'options', key 'QueryOpt'. Value '{value}' is not recognized. "
					f"Valid values: {', '.join([x.name for x in Opts.ParseMode])}")
			self.instr_options_parse_mode = enum_value

		# Instrument object settings
		value = self._get_driversetup_item('QueryInstrumentStatus')
		if value:
			self.instrument_status_check = Conv.str_to_bool(value)

		value = self._get_driversetup_item('SimulationIdnString')
		if value:
			# Use the '*' instead of the ',' in the value to avoid comma as token delimiter
			self.instrument_simulation_idn_string = value.replace('*', ',')

		# Core object settings
		value = self._get_driversetup_item('Simulate')
		if value:
			self.simulating = Conv.str_to_bool(value)

		value = self._get_driversetup_item('SupportedInstrModels')
		if value:
			self.supported_instr_models = [*map(trim_str_response, value.split('/'))]

		value = self._get_driversetup_item('SupportedIdnPatterns')
		if value:
			self.supported_idn_patterns = [*map(trim_str_response, value.split('/'))]

		# Profile has the ultimate priority.
		value = self._get_driversetup_item('Profile')
		if value:
			val_low = value.lower()

			if val_low == 'hm8123':
				self.term_char = '\r'
				self.assure_write_with_tc = True
				self.cmd_idn = 'IDN'
				self.cmd_reset = 'RST'
				self.skip_status_system_setting = True
				self.skip_clear_status = True
				self.disable_opc_query = True
				self.instrument_status_check = False
				self.stb_in_error_check = False

			elif val_low == 'cmq':
				self.term_char = '\r'
				self.assure_write_with_tc = True
				self.skip_status_system_setting = True
				self.skip_clear_status = True
				self.disable_opc_query = True
				self.instrument_status_check = False
				self.stb_in_error_check = False

			elif val_low == 'minimal':
				self.assure_write_with_tc = True
				self.skip_status_system_setting = True
				self.skip_clear_status = True
				self.disable_opc_query = True
				self.instrument_status_check = False
				self.stb_in_error_check = False

			else:
				raise ValueError(f"Unknown value in InitWithOptions string 'options', key 'Profile', value '{value}'. Valid values: HM8123, CMQ")



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal import Conversions
from .. import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SconfigurationCls:
	"""Sconfiguration commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sconfiguration", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.BbSystemConfiguration:
		"""SCPI: SCONfiguration:MODE \n
		Snippet: value: enums.BbSystemConfiguration = driver.sconfiguration.get_mode() \n
		Switches between standard mode and ARB mode for envelope tracking. \n
			:return: configuration: STANdard| AFETracking STANdard Standard mode used for signal generation. AFETracking ARB foe Envelope Tracking: enables the usage of an extra baseband for enabling the envelope tracking ARB generation.
		"""
		response = self._core.io.query_str('SCONfiguration:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.BbSystemConfiguration)

	def set_mode(self, configuration: enums.BbSystemConfiguration) -> None:
		"""SCPI: SCONfiguration:MODE \n
		Snippet: driver.sconfiguration.set_mode(configuration = enums.BbSystemConfiguration.AFETracking) \n
		Switches between standard mode and ARB mode for envelope tracking. \n
			:param configuration: STANdard| AFETracking STANdard Standard mode used for signal generation. AFETracking ARB foe Envelope Tracking: enables the usage of an extra baseband for enabling the envelope tracking ARB generation.
		"""
		param = Conversions.enum_scalar_to_str(configuration, enums.BbSystemConfiguration)
		self._core.io.write(f'SCONfiguration:MODE {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InfoCls:
	"""Info commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("info", core, parent)

	def get_psequencer(self) -> str:
		"""SCPI: [SOURce]:BB:INFO:PSEQuencer \n
		Snippet: value: str = driver.source.bb.info.get_psequencer() \n
		Returns the baseband pulse sequencer information. \n
			:return: info_xml_string: string
		"""
		response = self._core.io.query_str('SOURce:BB:INFO:PSEQuencer?')
		return trim_str_response(response)



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal import Conversions
from .. import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	# noinspection PyTypeChecker
	def get_border(self) -> enums.ByteOrder:
		"""SCPI: FORMat:BORDer \n
		Snippet: value: enums.ByteOrder = driver.formatPy.get_border() \n
		Determines the sequence of bytes within a binary block. This only affects blocks which use the IEEE754 format internally. \n
			:return: border: NORMal| SWAPped NORMal The instrument expects (with setting commands) and sends (with queries) the least significant byte of each IEEE754 floating-point number first and the most significant byte last. SWAPped The instrument expects (with setting commands) and sends (with queries) the most significant byte of each IEEE754 floating-point number first and the least significant byte last.
		"""
		response = self._core.io.query_str('FORMat:BORDer?')
		return Conversions.str_to_scalar_enum(response, enums.ByteOrder)

	def set_border(self, border: enums.ByteOrder) -> None:
		"""SCPI: FORMat:BORDer \n
		Snippet: driver.formatPy.set_border(border = enums.ByteOrder.NORMal) \n
		Determines the sequence of bytes within a binary block. This only affects blocks which use the IEEE754 format internally. \n
			:param border: NORMal| SWAPped NORMal The instrument expects (with setting commands) and sends (with queries) the least significant byte of each IEEE754 floating-point number first and the most significant byte last. SWAPped The instrument expects (with setting commands) and sends (with queries) the most significant byte of each IEEE754 floating-point number first and the least significant byte last.
		"""
		param = Conversions.enum_scalar_to_str(border, enums.ByteOrder)
		self._core.io.write(f'FORMat:BORDer {param}')

	# noinspection PyTypeChecker
	def get_sregister(self) -> enums.FormStatReg:
		"""SCPI: FORMat:SREGister \n
		Snippet: value: enums.FormStatReg = driver.formatPy.get_sregister() \n
		Determines the numerical format which is returned when the status registers are queried. \n
			:return: format_py: ASCii| BINary| HEXadecimal| OCTal ASCii The register content is returned as a decimal number. BINary The register content is returned as a binary number. #B is placed in front of the number. HEXadecimal The register content is returned as a hexadecimal number. #H is placed in front of the number. OCTal The register content is returned as an octal number. #Q is placed in front of the number.
		"""
		response = self._core.io.query_str('FORMat:SREGister?')
		return Conversions.str_to_scalar_enum(response, enums.FormStatReg)

	def set_sregister(self, format_py: enums.FormStatReg) -> None:
		"""SCPI: FORMat:SREGister \n
		Snippet: driver.formatPy.set_sregister(format_py = enums.FormStatReg.ASCii) \n
		Determines the numerical format which is returned when the status registers are queried. \n
			:param format_py: ASCii| BINary| HEXadecimal| OCTal ASCii The register content is returned as a decimal number. BINary The register content is returned as a binary number. #B is placed in front of the number. HEXadecimal The register content is returned as a hexadecimal number. #H is placed in front of the number. OCTal The register content is returned as an octal number. #Q is placed in front of the number.
		"""
		param = Conversions.enum_scalar_to_str(format_py, enums.FormStatReg)
		self._core.io.write(f'FORMat:SREGister {param}')

	# noinspection PyTypeChecker
	def get_data(self) -> enums.FormData:
		"""SCPI: FORMat:[DATA] \n
		Snippet: value: enums.FormData = driver.formatPy.get_data() \n
		Determines the data format which the R&S SGT uses to return data. When data is transferred from the control computer to
		the instrument, the instrument detects the data format automatically. In this case, the value set here is irrelevant. \n
			:return: data: ASCii| PACKed ASCii Numerical data is transferred as plain text separated by commas. PACKed Numerical data is transferred as binary block data. The format within the binary data depends on the command. The various binary data formats are explained in the description of the parameter types.
		"""
		response = self._core.io.query_str('FORMat:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.FormData)

	def set_data(self, data: enums.FormData) -> None:
		"""SCPI: FORMat:[DATA] \n
		Snippet: driver.formatPy.set_data(data = enums.FormData.ASCii) \n
		Determines the data format which the R&S SGT uses to return data. When data is transferred from the control computer to
		the instrument, the instrument detects the data format automatically. In this case, the value set here is irrelevant. \n
			:param data: ASCii| PACKed ASCii Numerical data is transferred as plain text separated by commas. PACKed Numerical data is transferred as binary block data. The format within the binary data depends on the command. The various binary data formats are explained in the description of the parameter types.
		"""
		param = Conversions.enum_scalar_to_str(data, enums.FormData)
		self._core.io.write(f'FORMat:DATA {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RoscillatorCls:
	"""Roscillator commands group definition. 6 total commands, 3 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("roscillator", core, parent)

	@property
	def external(self):
		"""external commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_external'):
			from .External import ExternalCls
			self._external = ExternalCls(self._core, self._cmd_group)
		return self._external

	@property
	def output(self):
		"""output commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_output'):
			from .Output import OutputCls
			self._output = OutputCls(self._core, self._cmd_group)
		return self._output

	@property
	def internal(self):
		"""internal commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_internal'):
			from .Internal import InternalCls
			self._internal = InternalCls(self._core, self._cmd_group)
		return self._internal

	# noinspection PyTypeChecker
	def get_source(self) -> enums.SourceInt:
		"""SCPI: [SOURce<HW>]:ROSCillator:SOURce \n
		Snippet: value: enums.SourceInt = driver.source.roscillator.get_source() \n
		Select the reference oscillator signal source. \n
			:return: source: INTernal| EXTernal
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:ROSCillator:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.SourceInt)

	def set_source(self, source: enums.SourceInt) -> None:
		"""SCPI: [SOURce<HW>]:ROSCillator:SOURce \n
		Snippet: driver.source.roscillator.set_source(source = enums.SourceInt.EXTernal) \n
		Select the reference oscillator signal source. \n
			:param source: INTernal| EXTernal
		"""
		param = Conversions.enum_scalar_to_str(source, enums.SourceInt)
		self._core.io.write(f'SOURce<HwInstance>:ROSCillator:SOURce {param}')

	def clone(self) -> 'RoscillatorCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RoscillatorCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class QcomponentCls:
	"""Qcomponent commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("qcomponent", core, parent)

	def set(self, qpart: float, path=repcap.Path.Default) -> None:
		"""SCPI: [SOURce]:BB:IMPairment:RF<CH>:LEAKage:Q \n
		Snippet: driver.source.bb.impairment.rf.leakage.qcomponent.set(qpart = 1.0, path = repcap.Path.Default) \n
		No command help available \n
			:param qpart: No help available
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rf')
		"""
		param = Conversions.decimal_value_to_str(qpart)
		path_cmd_val = self._cmd_group.get_repcap_cmd_value(path, repcap.Path)
		self._core.io.write(f'SOURce:BB:IMPairment:RF{path_cmd_val}:LEAKage:Q {param}')

	def get(self, path=repcap.Path.Default) -> float:
		"""SCPI: [SOURce]:BB:IMPairment:RF<CH>:LEAKage:Q \n
		Snippet: value: float = driver.source.bb.impairment.rf.leakage.qcomponent.get(path = repcap.Path.Default) \n
		No command help available \n
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rf')
			:return: qpart: No help available"""
		path_cmd_val = self._cmd_group.get_repcap_cmd_value(path, repcap.Path)
		response = self._core.io.query_str(f'SOURce:BB:IMPairment:RF{path_cmd_val}:LEAKage:Q?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SubnetCls:
	"""Subnet commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("subnet", core, parent)

	def get_mask(self) -> str:
		"""SCPI: SYSTem:COMMunicate:NETWork:[IPADdress]:SUBNet:MASK \n
		Snippet: value: str = driver.system.communicate.network.ipAddress.subnet.get_mask() \n
		Sets the subnet mask. \n
			:return: mask: string
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:NETWork:IPADdress:SUBNet:MASK?')
		return trim_str_response(response)

	def set_mask(self, mask: str) -> None:
		"""SCPI: SYSTem:COMMunicate:NETWork:[IPADdress]:SUBNet:MASK \n
		Snippet: driver.system.communicate.network.ipAddress.subnet.set_mask(mask = '1') \n
		Sets the subnet mask. \n
			:param mask: string
		"""
		param = Conversions.value_to_quoted_str(mask)
		self._core.io.write(f'SYSTem:COMMunicate:NETWork:IPADdress:SUBNet:MASK {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CouplingCls:
	"""Coupling commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("coupling", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:AWGN:BWIDth:COUPling:[STATe] \n
		Snippet: value: bool = driver.source.awgn.bandwidth.coupling.get_state() \n
		No command help available \n
			:return: awgn_bw_coup_state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AWGN:BWIDth:COUPling:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, awgn_bw_coup_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:AWGN:BWIDth:COUPling:[STATe] \n
		Snippet: driver.source.awgn.bandwidth.coupling.set_state(awgn_bw_coup_state = False) \n
		No command help available \n
			:param awgn_bw_coup_state: No help available
		"""
		param = Conversions.bool_to_str(awgn_bw_coup_state)
		self._core.io.write(f'SOURce<HwInstance>:AWGN:BWIDth:COUPling:STATe {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TimeCls:
	"""Time commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("time", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.ArbMultCarrSigDurMod:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:TIME:MODE \n
		Snippet: value: enums.ArbMultCarrSigDurMod = driver.source.bb.arbitrary.mcarrier.time.get_mode() \n
		Selects the mode for calculating the resulting signal period of the multi carrier waveform. The resulting period is
		always calculated for all carriers in the carrier table irrespective of their state (ON/OFF) . \n
			:return: mode: LONG| SHORt| LCM | USER LONG The resulting signal period is defined by the longest I/Q file in the carrier table. Shorter I/Q files are periodically repeated. SHORt The resulting signal period is defined by the shortest I/Q file in the carrier table. Only the first part of longer I/Q files is used. USER The signal period can be set with command [:SOURcehw]:BB:ARBitrary:MCARrier:TIME. Shorter I/Q files are repeated periodically, and only the first part of longer I/Q files is used. LCM The output file duration is the least common multiple of all input file durations.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:MCARrier:TIME:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ArbMultCarrSigDurMod)

	def set_mode(self, mode: enums.ArbMultCarrSigDurMod) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:TIME:MODE \n
		Snippet: driver.source.bb.arbitrary.mcarrier.time.set_mode(mode = enums.ArbMultCarrSigDurMod.LCM) \n
		Selects the mode for calculating the resulting signal period of the multi carrier waveform. The resulting period is
		always calculated for all carriers in the carrier table irrespective of their state (ON/OFF) . \n
			:param mode: LONG| SHORt| LCM | USER LONG The resulting signal period is defined by the longest I/Q file in the carrier table. Shorter I/Q files are periodically repeated. SHORt The resulting signal period is defined by the shortest I/Q file in the carrier table. Only the first part of longer I/Q files is used. USER The signal period can be set with command [:SOURcehw]:BB:ARBitrary:MCARrier:TIME. Shorter I/Q files are repeated periodically, and only the first part of longer I/Q files is used. LCM The output file duration is the least common multiple of all input file durations.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.ArbMultCarrSigDurMod)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:TIME:MODE {param}')

	def get_value(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:TIME \n
		Snippet: value: float = driver.source.bb.arbitrary.mcarrier.time.get_value() \n
		Sets the user-defined signal period. This setting is only possible for Signal Period Mode User (BB:ARB:MCAR:TIME:MODE
		USER) . \n
			:return: time: float Range: 0 to 1E9, Unit: s
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:MCARrier:TIME?')
		return Conversions.str_to_float(response)

	def set_value(self, time: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:TIME \n
		Snippet: driver.source.bb.arbitrary.mcarrier.time.set_value(time = 1.0) \n
		Sets the user-defined signal period. This setting is only possible for Signal Period Mode User (BB:ARB:MCAR:TIME:MODE
		USER) . \n
			:param time: float Range: 0 to 1E9, Unit: s
		"""
		param = Conversions.decimal_value_to_str(time)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:TIME {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MeasurementCls:
	"""Measurement commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("measurement", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:IQ:DPD:MEASurement:STATe \n
		Snippet: value: bool = driver.source.iq.dpd.measurement.get_state() \n
		Queries whether the interactions are competed. \n
			:return: measure_validity: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:DPD:MEASurement:STATe?')
		return Conversions.str_to_bool(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.CalDataMode:
		"""SCPI: CALibration:ROSCillator:DATA:MODE \n
		Snippet: value: enums.CalDataMode = driver.calibration.roscillator.data.get_mode() \n
		Defines whether the factory provided or a custom defined calibration value is used to adjust the reference oscillator. \n
			:return: mode: FACTory| CUSTomer
		"""
		response = self._core.io.query_str('CALibration:ROSCillator:DATA:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.CalDataMode)

	def set_mode(self, mode: enums.CalDataMode) -> None:
		"""SCPI: CALibration:ROSCillator:DATA:MODE \n
		Snippet: driver.calibration.roscillator.data.set_mode(mode = enums.CalDataMode.CUSTomer) \n
		Defines whether the factory provided or a custom defined calibration value is used to adjust the reference oscillator. \n
			:param mode: FACTory| CUSTomer
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.CalDataMode)
		self._core.io.write(f'CALibration:ROSCillator:DATA:MODE {param}')

	def get_value(self) -> int:
		"""SCPI: CALibration:ROSCillator:[DATA] \n
		Snippet: value: int = driver.calibration.roscillator.data.get_value() \n
		Sets the calibration value for the custom defined external adjustment. \n
			:return: data: integer Range: 0 to INT_MAX
		"""
		response = self._core.io.query_str('CALibration:ROSCillator:DATA?')
		return Conversions.str_to_int(response)

	def set_value(self, data: int) -> None:
		"""SCPI: CALibration:ROSCillator:[DATA] \n
		Snippet: driver.calibration.roscillator.data.set_value(data = 1) \n
		Sets the calibration value for the custom defined external adjustment. \n
			:param data: integer Range: 0 to INT_MAX
		"""
		param = Conversions.decimal_value_to_str(data)
		self._core.io.write(f'CALibration:ROSCillator:DATA {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SynchronizeCls:
	"""Synchronize commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("synchronize", core, parent)

	def get(self, time: str) -> str:
		"""SCPI: SYSTem:SRTime:SYNChronize \n
		Snippet: value: str = driver.system.srtime.synchronize.get(time = '1') \n
		No command help available \n
			:param time: No help available
			:return: time: No help available"""
		param = Conversions.value_to_quoted_str(time)
		response = self._core.io.query_str(f'SYSTem:SRTime:SYNChronize? {param}')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CorrectionCls:
	"""Correction commands group definition. 19 total commands, 3 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("correction", core, parent)

	@property
	def cset(self):
		"""cset commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_cset'):
			from .Cset import CsetCls
			self._cset = CsetCls(self._core, self._cmd_group)
		return self._cset

	@property
	def dexchange(self):
		"""dexchange commands group. 2 Sub-classes, 2 commands."""
		if not hasattr(self, '_dexchange'):
			from .Dexchange import DexchangeCls
			self._dexchange = DexchangeCls(self._core, self._cmd_group)
		return self._dexchange

	@property
	def zeroing(self):
		"""zeroing commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_zeroing'):
			from .Zeroing import ZeroingCls
			self._zeroing = ZeroingCls(self._core, self._cmd_group)
		return self._zeroing

	def get_value(self) -> float:
		"""SCPI: [SOURce<HW>]:CORRection:VALue \n
		Snippet: value: float = driver.source.correction.get_value() \n
		Queries the current value for user correction. \n
			:return: value: float Range: -100 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:CORRection:VALue?')
		return Conversions.str_to_float(response)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:CORRection:[STATe] \n
		Snippet: value: bool = driver.source.correction.get_state() \n
		Activates/deactivates level correction. Level correction is performed using the table which has been selected with the
		command [:SOURce<hw>]:CORRection:CSET[:SELect]. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:CORRection:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:[STATe] \n
		Snippet: driver.source.correction.set_state(state = False) \n
		Activates/deactivates level correction. Level correction is performed using the table which has been selected with the
		command [:SOURce<hw>]:CORRection:CSET[:SELect]. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:CORRection:STATe {param}')

	def clone(self) -> 'CorrectionCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CorrectionCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FileCls:
	"""File commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("file", core, parent)

	def set(self, file: str, carrier=repcap.Carrier.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CARRier<CH>:FILE \n
		Snippet: driver.source.bb.arbitrary.mcarrier.carrier.file.set(file = '1', carrier = repcap.Carrier.Default) \n
		Selects the file with I/Q data to be modulated onto the selected carrier. \n
			:param file: file name
			:param carrier: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mcarrier')
		"""
		param = Conversions.value_to_quoted_str(file)
		carrier_cmd_val = self._cmd_group.get_repcap_cmd_value(carrier, repcap.Carrier)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:CARRier{carrier_cmd_val}:FILE {param}')

	def get(self, carrier=repcap.Carrier.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CARRier<CH>:FILE \n
		Snippet: value: str = driver.source.bb.arbitrary.mcarrier.carrier.file.get(carrier = repcap.Carrier.Default) \n
		Selects the file with I/Q data to be modulated onto the selected carrier. \n
			:param carrier: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mcarrier')
			:return: file: file name"""
		carrier_cmd_val = self._cmd_group.get_repcap_cmd_value(carrier, repcap.Carrier)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:CARRier{carrier_cmd_val}:FILE?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImmediateCls:
	"""Immediate commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	def get_offset(self) -> float:
		"""SCPI: [SOURce<HW>]:POWer:[LEVel]:[IMMediate]:OFFSet \n
		Snippet: value: float = driver.source.power.level.immediate.get_offset() \n
		Specifies the constant level offset of a downstream attenuator/amplifier. If a level offset is entered, the level entered
		with POWer no longer corresponds to the RF output level. The following correlation applies: POWer = RF output level +
		POWer:OFFSet. Entering a level offset does not change the RF output level, but rather the query value of POWer. Only dB
		is permitted as the unit here. The linear units (V, W, etc.) are not permitted. \n
			:return: offset: float Range: -100 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:POWer:LEVel:IMMediate:OFFSet?')
		return Conversions.str_to_float(response)

	def set_offset(self, offset: float) -> None:
		"""SCPI: [SOURce<HW>]:POWer:[LEVel]:[IMMediate]:OFFSet \n
		Snippet: driver.source.power.level.immediate.set_offset(offset = 1.0) \n
		Specifies the constant level offset of a downstream attenuator/amplifier. If a level offset is entered, the level entered
		with POWer no longer corresponds to the RF output level. The following correlation applies: POWer = RF output level +
		POWer:OFFSet. Entering a level offset does not change the RF output level, but rather the query value of POWer. Only dB
		is permitted as the unit here. The linear units (V, W, etc.) are not permitted. \n
			:param offset: float Range: -100 to 100
		"""
		param = Conversions.decimal_value_to_str(offset)
		self._core.io.write(f'SOURce<HwInstance>:POWer:LEVel:IMMediate:OFFSet {param}')

	# noinspection PyTypeChecker
	def get_recall(self) -> enums.InclExcl:
		"""SCPI: [SOURce<HW>]:POWer:[LEVel]:[IMMediate]:RCL \n
		Snippet: value: enums.InclExcl = driver.source.power.level.immediate.get_recall() \n
		No command help available \n
			:return: rcl_excl_pow: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:POWer:LEVel:IMMediate:RCL?')
		return Conversions.str_to_scalar_enum(response, enums.InclExcl)

	def set_recall(self, rcl_excl_pow: enums.InclExcl) -> None:
		"""SCPI: [SOURce<HW>]:POWer:[LEVel]:[IMMediate]:RCL \n
		Snippet: driver.source.power.level.immediate.set_recall(rcl_excl_pow = enums.InclExcl.EXCLude) \n
		No command help available \n
			:param rcl_excl_pow: No help available
		"""
		param = Conversions.enum_scalar_to_str(rcl_excl_pow, enums.InclExcl)
		self._core.io.write(f'SOURce<HwInstance>:POWer:LEVel:IMMediate:RCL {param}')

	def get_amplitude(self) -> float:
		"""SCPI: [SOURce<HW>]:POWer:[LEVel]:[IMMediate]:[AMPLitude] \n
		Snippet: value: float = driver.source.power.level.immediate.get_amplitude() \n
		Sets the RF level at the RF output connector of the instrument. \n
			:return: amplitude: float Range: -120 to 25, Unit: dBm
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:POWer:LEVel:IMMediate:AMPLitude?')
		return Conversions.str_to_float(response)

	def set_amplitude(self, amplitude: float) -> None:
		"""SCPI: [SOURce<HW>]:POWer:[LEVel]:[IMMediate]:[AMPLitude] \n
		Snippet: driver.source.power.level.immediate.set_amplitude(amplitude = 1.0) \n
		Sets the RF level at the RF output connector of the instrument. \n
			:param amplitude: float Range: -120 to 25, Unit: dBm
		"""
		param = Conversions.decimal_value_to_str(amplitude)
		self._core.io.write(f'SOURce<HwInstance>:POWer:LEVel:IMMediate:AMPLitude {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ShapingCls:
	"""Shaping commands group definition. 19 total commands, 3 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("shaping", core, parent)

	@property
	def normalized(self):
		"""normalized commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_normalized'):
			from .Normalized import NormalizedCls
			self._normalized = NormalizedCls(self._core, self._cmd_group)
		return self._normalized

	@property
	def polynomial(self):
		"""polynomial commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_polynomial'):
			from .Polynomial import PolynomialCls
			self._polynomial = PolynomialCls(self._core, self._cmd_group)
		return self._polynomial

	@property
	def table(self):
		"""table commands group. 2 Sub-classes, 2 commands."""
		if not hasattr(self, '_table'):
			from .Table import TableCls
			self._table = TableCls(self._core, self._cmd_group)
		return self._table

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.DpdShapeMode:
		"""SCPI: [SOURce<HW>]:IQ:DPD:SHAPing:MODE \n
		Snippet: value: enums.DpdShapeMode = driver.source.iq.dpd.shaping.get_mode() \n
		Selects the method to define the correction coefficients. \n
			:return: shaping: TABLe| POLYnomial| NORMalized
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:DPD:SHAPing:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.DpdShapeMode)

	def set_mode(self, shaping: enums.DpdShapeMode) -> None:
		"""SCPI: [SOURce<HW>]:IQ:DPD:SHAPing:MODE \n
		Snippet: driver.source.iq.dpd.shaping.set_mode(shaping = enums.DpdShapeMode.NORMalized) \n
		Selects the method to define the correction coefficients. \n
			:param shaping: TABLe| POLYnomial| NORMalized
		"""
		param = Conversions.enum_scalar_to_str(shaping, enums.DpdShapeMode)
		self._core.io.write(f'SOURce<HwInstance>:IQ:DPD:SHAPing:MODE {param}')

	def clone(self) -> 'ShapingCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ShapingCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, carrier=repcap.Carrier.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CARRier<CH>:STATe \n
		Snippet: driver.source.bb.arbitrary.mcarrier.carrier.state.set(state = False, carrier = repcap.Carrier.Default) \n
		Enables/disables the selected carrier. \n
			:param state: 0| 1| OFF| ON
			:param carrier: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mcarrier')
		"""
		param = Conversions.bool_to_str(state)
		carrier_cmd_val = self._cmd_group.get_repcap_cmd_value(carrier, repcap.Carrier)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:CARRier{carrier_cmd_val}:STATe {param}')

	def get(self, carrier=repcap.Carrier.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CARRier<CH>:STATe \n
		Snippet: value: bool = driver.source.bb.arbitrary.mcarrier.carrier.state.get(carrier = repcap.Carrier.Default) \n
		Enables/disables the selected carrier. \n
			:param carrier: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mcarrier')
			:return: state: 0| 1| OFF| ON"""
		carrier_cmd_val = self._cmd_group.get_repcap_cmd_value(carrier, repcap.Carrier)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:CARRier{carrier_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)
